@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-16/Applications/Cxx/gdcmanon.cxx $
+  Module:  $URL$
 
   Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
@@ -33,7 +33,7 @@
 static void PrintVersion()
 {
   std::cout << "gdcmanon: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2010-08-18 12:22:07 +0200 (Wed, 18 Aug 2010) $";
+  const char date[] = "$Date$";
   std::cout << date << std::endl;
 }
 
@@ -230,7 +230,7 @@ static void PrintHelp()
   std::cout << "Dumb mode options:" << std::endl;
   std::cout << "     --empty   %d,%d           DICOM tag(s) to empty" << std::endl;
   std::cout << "     --remove  %d,%d           DICOM tag(s) to remove" << std::endl;
-  std::cout << "     --replace %d,%d,%s        DICOM tag(s) to replace" << std::endl;
+  std::cout << "     --replace %d,%d=%s        DICOM tag(s) to replace" << std::endl;
   std::cout << "General Options:" << std::endl;
   std::cout << "  -V --verbose                more verbose (warning+error)." << std::endl;
   std::cout << "  -W --warning                print warning info." << std::endl;
@@ -437,7 +437,7 @@ int main(int argc, char *argv[])
             ss >> std::hex >> dummy;
             assert( tag.GetElement() == dummy );
             ss >> cdummy;
-            assert( cdummy == ',' );
+            assert( cdummy == ',' || cdummy == '=' );
             std::string str;
             ss >> str;
             replace_tags_value.push_back( std::make_pair(tag, str) );
@@ -521,9 +521,9 @@ int main(int argc, char *argv[])
       files.push_back( argv[optind++] );
       }
     //printf ("\n");
-    if( files.size() == 2 
+    if( files.size() == 2
       && filename.empty()
-      && outfilename.empty() 
+      && outfilename.empty()
     )
       {
       filename = files[0];
@@ -580,7 +580,7 @@ int main(int argc, char *argv[])
 #ifndef GDCM_USE_SYSTEM_OPENSSL
     std::cerr << "OpenSSL was not configured." << std::endl;
     return 1;
-#endif 
+#endif
     }
 
   // by default AES 256
@@ -786,4 +786,3 @@ int main(int argc, char *argv[])
     }
   return 0;
 }
-
