@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-16/Applications/Cxx/gdcmdump.cxx $
+  Module:  $URL$
 
   Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
@@ -83,6 +83,7 @@ int DoOperation(const std::string & filename)
 
 int PrintASN1(const std::string & filename, bool verbose)
 {
+  (void)verbose;
   gdcm::Reader reader;
   reader.SetFileName( filename.c_str() );
   if( !reader.Read() )
@@ -121,6 +122,7 @@ int PrintASN1(const std::string & filename, bool verbose)
 
 int PrintPDB(const std::string & filename, bool verbose)
 {
+  (void)verbose;
   gdcm::Reader reader;
   reader.SetFileName( filename.c_str() );
   if( !reader.Read() )
@@ -246,7 +248,7 @@ int PrintCSA(const std::string & filename)
 void PrintVersion()
 {
   std::cout << "gdcmdump: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2010-06-23 18:15:58 +0200 (Wed, 23 Jun 2010) $";
+  const char date[] = "$Date$";
   std::cout << date << std::endl;
 }
 
@@ -493,7 +495,7 @@ int main (int argc, char *argv[])
     gdcm::Trace::SetWarning( verbose );
     gdcm::Trace::SetError( verbose);
     }
-   
+
   if( mapuidnames )
     {
     std::cerr << "Not handled for now" << std::endl;
@@ -593,7 +595,7 @@ SLTHICK ->  Slice Thickness
 
 
 Full list:
- 
+
 ANREF "IC"
 ANREF "NA"
 ANREF "SN"
