@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-16/Applications/Cxx/gdcmgendir.cxx $
+  Module:  $URL$
 
   Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
@@ -13,7 +13,7 @@
 
 =========================================================================*/
 /*
- * Implementation of General Purpose CD-R Interchange / STD-GEN-CD DICOMDIR in GDCM 
+ * Implementation of General Purpose CD-R Interchange / STD-GEN-CD DICOMDIR in GDCM
  */
 #include "gdcmReader.h"
 #include "gdcmWriter.h"
@@ -31,7 +31,7 @@
 void PrintVersion()
 {
   std::cout << "gdcmgendir: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2010-06-23 18:15:58 +0200 (Wed, 23 Jun 2010) $";
+  const char date[] = "$Date$";
   std::cout << date << std::endl;
 }
 
@@ -47,7 +47,6 @@ void PrintHelp()
   std::cout << "  -r --recursive          recursive." << std::endl;
   std::cout << "     --descriptor          descriptor." << std::endl;
   std::cout << "     --root-uid               Root UID." << std::endl;
-  std::cout << "     --resources-path         Resources path." << std::endl;
   std::cout << "General Options:" << std::endl;
   std::cout << "  -V --verbose   more verbose (warning+error)." << std::endl;
   std::cout << "  -W --warning   print warning info." << std::endl;
@@ -57,7 +56,6 @@ void PrintHelp()
   std::cout << "  -v --version   print version." << std::endl;
   std::cout << "Env var:" << std::endl;
   std::cout << "  GDCM_ROOT_UID Root UID" << std::endl;
-  std::cout << "  GDCM_RESOURCES_PATH path pointing to resources files (Part3.xml, ...)" << std::endl;
 }
 
 int main(int argc, char *argv[])
@@ -206,9 +204,9 @@ int main(int argc, char *argv[])
       files.push_back( argv[optind++] );
       }
     //printf ("\n");
-    if( files.size() >= 2 
+    if( files.size() >= 2
       && filename.empty()
-      && outfilename.empty() 
+      && outfilename.empty()
     )
       {
       filename = files[0].c_str();
@@ -237,14 +235,14 @@ int main(int argc, char *argv[])
     return 0;
     }
 
-  if( filename.empty() 
+  if( filename.empty()
     || outfilename.empty() )
     {
     //std::cerr << "Need input file (-i)\n";
     PrintHelp();
     return 1;
     }
-  
+
   // Debug is a little too verbose
   gdcm::Trace::SetDebug( debug );
   gdcm::Trace::SetWarning( warning );
@@ -349,4 +347,3 @@ int main(int argc, char *argv[])
 
   return res;
 }
-
