@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-16/Applications/Cxx/gdcmimg.cxx $
+  Module:  $URL$
 
   Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
@@ -38,7 +38,7 @@
  *   DICOM avi  <->  avi
  *   DICOM wav  <->  wav
  *   DICOM pdf  <->  pdf
- * Todo: check compat API with jhead 
+ * Todo: check compat API with jhead
  */
 #include "gdcmFilename.h"
 #include "gdcmDirectory.h"
@@ -110,7 +110,7 @@ void FillRegionWithColor(char *cp, const unsigned int *dims, const unsigned int
 void PrintVersion()
 {
   std::cout << "gdcmimg: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2010-07-07 18:10:49 +0200 (Wed, 07 Jul 2010) $";
+  const char date[] = "$Date$";
   std::cout << date << std::endl;
 }
 
@@ -145,7 +145,7 @@ void PrintHelp()
   std::cout << "  -v --version   print version." << std::endl;
   std::cout << "Env var:" << std::endl;
   std::cout << "  GDCM_ROOT_UID Root UID" << std::endl;
-/* 
+/*
  * Default behavior for root UID is:
  * By default the GDCM one is used
  * If GDCM_ROOT_UID is set, then use this one instead
@@ -205,12 +205,13 @@ bool AddStudyDateTime(gdcm::DataSet &ds, const char *filename )
 }
 
 
-bool AddUIDs(int sopclassuid, std::string const & sopclass, std::string const & study_uid, std::string const & series_uid, gdcm::DataSet& ds)
+bool AddUIDs(int sopclassuid, std::string const & sopclass, std::string const & study_uid, std::string const & series_uid, gdcm::PixmapWriter& writer)
 {
+  gdcm::DataSet & ds = writer.GetFile().GetDataSet();
+  gdcm::MediaStorage ms = gdcm::MediaStorage::MS_END;
   if( sopclassuid )
     {
     // Is it by value or by name ?
-    gdcm::MediaStorage ms = gdcm::MediaStorage::MS_END;
     if( gdcm::UIDGenerator::IsValid( sopclass.c_str() ) )
       {
       ms = gdcm::MediaStorage::GetMSType( sopclass.c_str() );
@@ -236,6 +237,20 @@ bool AddUIDs(int sopclassuid, std::string const & sopclass, std::string const &
     de.SetVR( gdcm::Attribute<0x0008, 0x0016>::GetVR() );
     ds.Insert( de );
     }
+  else
+    {
+    // FIXME we are copying the default behavior of gdcm.PixmapWriter here:
+    ms = gdcm::MediaStorage::SecondaryCaptureImageStorage;
+    }
+
+  gdcm::Pixmap &image = writer.GetPixmap();
+  if( ms.GetModalityDimension() < image.GetNumberOfDimensions() )
+    {
+    std::cerr << "Could not find Modality" << std::endl;
+    return false;
+    }
+
+
         {
         gdcm::DataElement de( gdcm::Tag(0x0020,0x000d) ); // Study
         de.SetByteValue( study_uid.c_str(), study_uid.size() );
@@ -258,7 +273,7 @@ bool PopulateSingeFile( gdcm::PixmapWriter & writer, gdcm::SequenceOfFragments *
 {
   /*
    * FIXME: when JPEG contains JFIF marker, we should only read them
-   * during header parsing but discard them when copying the JPG byte stream into 
+   * during header parsing but discard them when copying the JPG byte stream into
    * the encapsulated Pixel Data Element...
    */
   std::ifstream is(filename);
@@ -316,16 +331,18 @@ bool Populate( gdcm::PixmapWriter & writer, gdcm::ImageCodec & jpeg, gdcm::Direc
   image.SetNumberOfDimensions( 2 );
   if( filenames.size() > 1 )
     {
-  image.SetNumberOfDimensions( 3 );
+    image.SetNumberOfDimensions( 3 );
     }
 
-    gdcm::SmartPointer<gdcm::SequenceOfFragments> sq = new gdcm::SequenceOfFragments;
+  gdcm::SmartPointer<gdcm::SequenceOfFragments> sq = new gdcm::SequenceOfFragments;
   for(; it != filenames.end(); ++it)
     {
     b = b && PopulateSingeFile( writer, sq, jpeg, it->c_str() );
     }
   if( filenames.size() > 1 )
-  image.SetDimension(2,  filenames.size() );
+    {
+    image.SetDimension(2,  filenames.size() );
+    }
 
   return b;
 }
@@ -412,8 +429,8 @@ int main (int argc, char *argv[])
         {"series-uid", 1, &seriesuid, 1},
         {"root-uid", 1, &rootuid, 1}, // specific Root (not GDCM)
         {"sop-class-uid", 1, &sopclassuid, 1}, // specific SOP Class UID
-        {"endian", 1, &endian, 1}, // 
-        {"sign", 1, &sign, 1}, // 
+        {"endian", 1, &endian, 1}, //
+        {"sign", 1, &sign, 1}, //
 
 // General options !
         {"verbose", 0, &verbose, 1},
@@ -595,9 +612,9 @@ int main (int argc, char *argv[])
       files.push_back( argv[optind++] );
       }
     //printf ("\n");
-    if( files.size() >= 2 
+    if( files.size() >= 2
       && filename.IsEmpty()
-      && outfilename.IsEmpty() 
+      && outfilename.IsEmpty()
     )
       {
       filename = files[0].c_str();
@@ -700,7 +717,7 @@ int main (int argc, char *argv[])
     {
     if( pixelsign != 0 && pixelsign != 1 ) return 1;
     }
- 
+
   const char *inputextension = filename.GetExtension();
   const char *outputextension = outfilename.GetExtension();
   //if( !inputextension || !outputextension ) return 1;
@@ -744,7 +761,7 @@ int main (int argc, char *argv[])
         }
 
       if( !Populate( writer, raw, filenames ) ) return 1;
-      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer.GetFile().GetDataSet() ) ) return 1;
+      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer ) ) return 1;
 
       writer.SetFileName( outfilename );
       if( !writer.Write() )
@@ -777,7 +794,7 @@ int main (int argc, char *argv[])
       rle.SetPhotometricInterpretation( pi );
 
       if( !Populate( writer, rle, filenames ) ) return 1;
-      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer.GetFile().GetDataSet() ) ) return 1;
+      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer ) ) return 1;
 
       writer.SetFileName( outfilename );
       if( !writer.Write() )
@@ -788,14 +805,14 @@ int main (int argc, char *argv[])
       return 0;
       }
 
-    if(  gdcm::System::StrCaseCmp(inputextension,".pgm") == 0 
-      || gdcm::System::StrCaseCmp(inputextension,".pnm") == 0 
+    if(  gdcm::System::StrCaseCmp(inputextension,".pgm") == 0
+      || gdcm::System::StrCaseCmp(inputextension,".pnm") == 0
       || gdcm::System::StrCaseCmp(inputextension,".ppm") == 0 )
       {
       gdcm::PNMCodec pnm;
       gdcm::PixmapWriter writer;
       if( !Populate( writer, pnm, filenames ) ) return 1;
-      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer.GetFile().GetDataSet() ) ) return 1;
+      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer ) ) return 1;
 
       writer.SetFileName( outfilename );
       if( !writer.Write() )
@@ -811,7 +828,7 @@ int main (int argc, char *argv[])
       gdcm::JPEGLSCodec jpeg;
       gdcm::PixmapWriter writer;
       if( !Populate( writer, jpeg, filenames ) ) return 1;
-      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer.GetFile().GetDataSet() ) ) return 1;
+      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer ) ) return 1;
 
       writer.SetFileName( outfilename );
       if( !writer.Write() )
@@ -822,7 +839,7 @@ int main (int argc, char *argv[])
       return 0;
       }
 
-    if(  gdcm::System::StrCaseCmp(inputextension,".jp2") == 0 
+    if(  gdcm::System::StrCaseCmp(inputextension,".jp2") == 0
       || gdcm::System::StrCaseCmp(inputextension,".j2k") == 0
       || gdcm::System::StrCaseCmp(inputextension,".j2c") == 0
       || gdcm::System::StrCaseCmp(inputextension,".jpc") == 0 )
@@ -834,7 +851,7 @@ int main (int argc, char *argv[])
       gdcm::JPEG2000Codec jpeg;
       gdcm::PixmapWriter writer;
       if( !Populate( writer, jpeg, filenames ) ) return 1;
-      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer.GetFile().GetDataSet() ) ) return 1;
+      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer ) ) return 1;
 
       writer.SetFileName( outfilename );
       if( !writer.Write() )
@@ -846,7 +863,7 @@ int main (int argc, char *argv[])
 
       }
 
-    if(  gdcm::System::StrCaseCmp(inputextension,".jpg") == 0 
+    if(  gdcm::System::StrCaseCmp(inputextension,".jpg") == 0
       || gdcm::System::StrCaseCmp(inputextension,".jpeg") == 0
       || gdcm::System::StrCaseCmp(inputextension,".ljpg") == 0
       || gdcm::System::StrCaseCmp(inputextension,".ljpeg") == 0 )
@@ -858,7 +875,7 @@ int main (int argc, char *argv[])
       jpeg.SetPixelFormat( pf );
       gdcm::PixmapWriter writer;
       if( !Populate( writer, jpeg, filenames ) ) return 1;
-      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer.GetFile().GetDataSet() ) ) return 1;
+      if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer ) ) return 1;
 
       writer.SetFileName( outfilename );
       if( !writer.Write() )
@@ -885,8 +902,8 @@ int main (int argc, char *argv[])
 
   if ( outputextension )
     {
-    if(  gdcm::System::StrCaseCmp(outputextension,".pgm") == 0 
-      || gdcm::System::StrCaseCmp(outputextension,".pnm") == 0 
+    if(  gdcm::System::StrCaseCmp(outputextension,".pgm") == 0
+      || gdcm::System::StrCaseCmp(outputextension,".pnm") == 0
       || gdcm::System::StrCaseCmp(outputextension,".ppm") == 0 )
       {
       gdcm::PNMCodec pnm;
@@ -922,7 +939,7 @@ int main (int argc, char *argv[])
     gdcm::SmartPointer<gdcm::Pixmap> image = new gdcm::Pixmap;
     image->SetNumberOfDimensions( 2 ); // good default
     const unsigned int *dims = imageori.GetDimensions();
-    if ( region[0] > region[1] 
+    if ( region[0] > region[1]
       || region[2] > region[3]
       || region[4] > region[5]
       || region[1] > dims[0]
@@ -931,12 +948,12 @@ int main (int argc, char *argv[])
       {
       if( imageori.GetNumberOfDimensions() == 2 )
         {
-        std::cerr << "bogus region. Should be at most: (" << dims[0] << "," << dims[1] << "," 
+        std::cerr << "bogus region. Should be at most: (" << dims[0] << "," << dims[1] << ","
           /*<< dims[2]*/ << ")" << std::endl;
         }
       else
         {
-        std::cerr << "bogus region. Should be at most: (" << dims[0] << "," << dims[1] << "," 
+        std::cerr << "bogus region. Should be at most: (" << dims[0] << "," << dims[1] << ","
           << dims[2] << ")" << std::endl;
         }
       return 1;
@@ -988,7 +1005,7 @@ int main (int argc, char *argv[])
       {
       image->SetTransferSyntax( gdcm::TransferSyntax::ExplicitVRLittleEndian );
       }
-    else 
+    else
       {
       assert( ts.IsImplicit() );
       image->SetTransferSyntax( gdcm::TransferSyntax::ImplicitVRLittleEndian );
@@ -1006,7 +1023,7 @@ int main (int argc, char *argv[])
     // (0008,2111) ST [MedCom Resample v]                      #  18, 1 DerivationDescriptio
     gdcm::Attribute<0x0008,0x2111> at2;
     std::ostringstream os;
-    os << "Fill Region [" 
+    os << "Fill Region ["
       << region[0] << "," << region[1] << ","
       << region[2] << "," << region[3] << ","
       << region[4] << "," << region[5] << "] with color value=" << std::hex << (int)color;
@@ -1018,12 +1035,12 @@ int main (int argc, char *argv[])
 > 1. Replace Value #1 of Image Type by 'DERIVED'
 
 Don't do that ... leave Image Type alone (unless you are changing
-the UID ... vide infra). 
+the UID ... vide infra).
 */
 #if 0
     // (0008,0008) CS [ORIGINAL\SECONDARY]                     #  18, 2 ImageType
     gdcm::Attribute<0x0008,0x0008> at3;
-    static const gdcm::CSComp values[] = {"DERIVED","SECONDARY"}; 
+    static const gdcm::CSComp values[] = {"DERIVED","SECONDARY"};
     at3.SetValues( values, 2, true ); // true => copy data !
     if( ds.FindDataElement( at3.GetTag() ) )
       {
@@ -1047,4 +1064,3 @@ the UID ... vide infra).
 
   return 0;
 }
-
