@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-16/Applications/Cxx/gdcmpdf.cxx $
+  Module:  $URL$
 
   Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
@@ -119,7 +119,7 @@ std::string getInfoString(Dict *infoDict, const char *key, UnicodeMap *uMap)
       isUnicode = gTrue;
       i = 2;
       }
-    else 
+    else
       {
       isUnicode = gFalse;
       i = 0;
@@ -149,7 +149,7 @@ std::string getInfoString(Dict *infoDict, const char *key, UnicodeMap *uMap)
 void PrintVersion()
 {
   std::cout << "gdcmpdf: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2010-06-23 18:15:58 +0200 (Wed, 23 Jun 2010) $";
+  const char date[] = "$Date$";
   std::cout << date << std::endl;
 }
 
@@ -286,7 +286,7 @@ int main (int argc, char *argv[])
       filename = argv[optind];
       outfilename = argv[optind+1];
       }
-    else 
+    else
       {
       PrintHelp();
       return 1;
@@ -652,4 +652,3 @@ http://msdn.microsoft.com/en-us/library/078sfkak(VS.80).aspx
 
   return 0;
 }
-
