@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-16/Applications/Cxx/gdcmraw.cxx $
+  Module:  $URL$
 
   Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
@@ -48,7 +48,7 @@
 void PrintVersion()
 {
   std::cout << "gdcmraw: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2010-06-23 18:15:58 +0200 (Wed, 23 Jun 2010) $";
+  const char date[] = "$Date$";
   std::cout << date << std::endl;
 }
 
@@ -228,9 +228,9 @@ int main(int argc, char *argv[])
       files.push_back( argv[optind++] );
       }
     //printf ("\n");
-    if( files.size() == 2 
+    if( files.size() == 2
       && filename.empty()
-      && outfilename.empty() 
+      && outfilename.empty()
     )
       {
       filename = files[0];
@@ -263,7 +263,7 @@ int main(int argc, char *argv[])
     PrintHelp();
     return 1;
     }
- 
+
   // Debug is a little too verbose
   gdcm::Trace::SetDebug( debug );
   gdcm::Trace::SetWarning( warning );
@@ -299,7 +299,7 @@ int main(int argc, char *argv[])
 
     std::ofstream output(outfilename.c_str(), std::ios::binary);
     output.write( buf, len );
-    
+
     delete[] buf;
     return 0;
     }
@@ -380,4 +380,3 @@ int main(int argc, char *argv[])
 
   return 0;
 }
-
