@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-16/Applications/Cxx/gdcmscanner.cxx $
+  Module:  $URL$
 
   Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
@@ -45,7 +45,7 @@
 void PrintVersion()
 {
   std::cout << "gdcmscanner: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2010-06-23 18:15:58 +0200 (Wed, 23 Jun 2010) $";
+  const char date[] = "$Date$";
   std::cout << date << std::endl;
 }
 
@@ -249,9 +249,9 @@ int main(int argc, char *argv[])
     {
     std::cout << "Will parse: " << dirname << std::endl;
     std::cout << "Looking for tags: \n";
-    std::copy(tags.begin(), tags.end(), 
+    std::copy(tags.begin(), tags.end(),
       std::ostream_iterator<gdcm::Tag>( std::cout, "\n"));
-    std::copy(privatetags.begin(), privatetags.end(), 
+    std::copy(privatetags.begin(), privatetags.end(),
       std::ostream_iterator<gdcm::PrivateTag>( std::cout, "\n"));
     //std::cout << std::endl;
     }
@@ -282,4 +282,3 @@ int main(int argc, char *argv[])
 
   return 0;
 }
-
