@@ -46,6 +46,9 @@
 //-----------------------------------------------------------------------------
 //This is needed when compiling in debug mode
 #ifdef _MSC_VER
+// to allow construct such as: std::numeric_limits<int>::max() we need the following:
+// warning C4003: not enough actual parameters for macro 'max'
+#define NOMINMAX
 # pragma warning ( default : 4263 ) /* no override, call convention differs */
 // 'identifier' : class 'type' needs to have dll-interface to be used by
 // clients of class 'type2'
@@ -57,7 +60,7 @@
 #pragma warning ( disable : 4786 )
 //'identifier' : decorated name length exceeded, name was truncated
 #pragma warning ( disable : 4503 )
-// C++ exception specification ignored except to indicate a 
+// C++ exception specification ignored except to indicate a
 // function is not __declspec(nothrow)
 //#pragma warning ( disable : 4290 )
 // signed/unsigned mismatch
