@@ -72,14 +72,14 @@ public:
 
   const DictEntry &GetDictEntry(const Tag &tag) const
     {
-    MapDictEntry::const_iterator it = 
+    MapDictEntry::const_iterator it =
       DictInternal.find(tag);
     if (it == DictInternal.end())
       {
 #ifdef UNKNOWNPUBLICTAG
       // test.acr
       if( tag != Tag(0x28,0x15)
-        && tag != Tag(0x28,0x16) 
+        && tag != Tag(0x28,0x16)
         && tag != Tag(0x28,0x199)
         // gdcmData/TheralysGDCM1.dcm
         && tag != Tag(0x20,0x1)
@@ -100,12 +100,59 @@ public:
     return it->second;
     }
 
+  /// Function to return the Keyword from a Tag
+  const char *GetKeywordFromTag(Tag const & tag) const
+    {
+    MapDictEntry::const_iterator it =
+      DictInternal.find(tag);
+    if (it == DictInternal.end())
+      {
+      return NULL;
+      }
+    assert( DictInternal.count(tag) == 1 );
+    return it->second.GetKeyword();
+    }
+
+  /// Lookup DictEntry by keyword. Even if DICOM standard defines keyword
+  /// as being unique. The lookup table is built on Tag. Therefore
+  /// looking up a DictEntry by Keyword is more inefficient than looking up
+  /// by Tag.
+  const DictEntry &GetDictEntryByKeyword(const char *keyword, Tag & tag) const
+    {
+    MapDictEntry::const_iterator it =
+      DictInternal.begin();
+    if( keyword )
+      {
+      for(; it != DictInternal.end(); ++it)
+        {
+        if( strcmp( keyword, it->second.GetKeyword() ) == 0 )
+          {
+          // Found a match !
+          tag = it->first;
+          break;
+          }
+        }
+      }
+    else
+      {
+      it = DictInternal.end();
+      }
+    if (it == DictInternal.end())
+      {
+      tag = Tag(0xffff,0xffff);
+      it = DictInternal.find( tag );
+      return it->second;
+      }
+    assert( DictInternal.count(tag) == 1 );
+    return it->second;
+    }
+
   /// Inefficient way of looking up tag by name. Technically DICOM
   /// does not garantee uniqueness (and Curve / Overlay are there to prove it). But
   /// most of the time name is in fact uniq and can be uniquely link to a tag
   const DictEntry &GetDictEntryByName(const char *name, Tag & tag) const
     {
-    MapDictEntry::const_iterator it = 
+    MapDictEntry::const_iterator it =
       DictInternal.begin();
     if( name )
       {
@@ -186,7 +233,7 @@ public:
 #if defined(NDEBUG) && 0
     if( s == DictInternal.size() )
       {
-      MapDictEntry::iterator it = 
+      MapDictEntry::iterator it =
         DictInternal.find(tag);
       assert( it != DictInternal.end() );
       DictEntry &duplicate = it->second;
@@ -206,10 +253,19 @@ public:
 #endif
     assert( s < DictInternal.size() /*&& std::cout << tag << "," << de << std::endl*/ );
     }
+  /// Remove entry 'tag'. Return true on success (element was found
+  /// and remove). return false if element was not found.
+  bool RemoveDictEntry(const PrivateTag &tag)
+    {
+    MapDictEntry::size_type s =
+      DictInternal.erase(tag);
+    assert( s == 1 || s == 0 );
+    return s == 1;
+    }
   const DictEntry &GetDictEntry(const PrivateTag &tag) const
     {
     // if 0x10 -> return Private Creator
-    MapDictEntry::const_iterator it = 
+    MapDictEntry::const_iterator it =
       DictInternal.find(tag);
     if (it == DictInternal.end())
       {
@@ -232,8 +288,8 @@ public:
       const PrivateTag &t = it->first;
       const DictEntry &de = it->second;
       std::cout << "  <entry group=\"" << std::hex << std::setw(4)
-        << std::setfill('0') << t.GetGroup() << "\"" << 
-        " element=\"xx" << std::setw(2) << std::setfill('0')<< t.GetElement() << "\"" << " vr=\"" 
+        << std::setfill('0') << t.GetGroup() << "\"" <<
+        " element=\"xx" << std::setw(2) << std::setfill('0')<< t.GetElement() << "\"" << " vr=\""
         << de.GetVR() << "\" vm=\"" << de.GetVM() << "\" owner=\""
         << t.GetOwner();
       const char *name = de.GetName();
