@@ -33,6 +33,12 @@ public:
   template <typename TSwap>
   std::istream &Read(std::istream &is);
 
+  template <typename TSwap>
+  std::istream &ReadPreValue(std::istream &is);
+
+  template <typename TSwap>
+  std::istream &ReadValue(std::istream &is);
+
   template <typename TSwap>
   std::istream &ReadWithLength(std::istream &is, VL & length);
 
@@ -46,4 +52,3 @@ public:
 #include "gdcmCP246ExplicitDataElement.txx"
 
 #endif //GDCMCP246EXPLICITDATAELEMENT_H
-
