@@ -24,11 +24,8 @@ namespace gdcm
 {
   void DataElement::SetVLToUndefined() {
     assert( VRField == VR::SQ || VRField == VR::INVALID
-      || (VRField == VR::UN && IsUndefinedLength() ) );
-    //SequenceOfItems *sqi = GetSequenceOfItems();
+      || (VRField == VR::UN /*&& IsUndefinedLength()*/ ) );
     SequenceOfItems *sqi = dynamic_cast<SequenceOfItems*>(ValueField.GetPointer());
-    //SmartPointer<SequenceOfItems> sqi2 = GetValueAsSQ();
-    //SequenceOfItems *sqi = dynamic_cast<SequenceOfItems*>(&GetValue());
     if( sqi )
       {
       sqi->SetLengthToUndefined();
@@ -111,13 +108,16 @@ namespace gdcm
             const Tag itemPMSStart2(0x3f3f, 0x3f00);
 
             // same player ...
+            //this to fix a broken dicom implementation
+            //for philips medical systems
             std::stringstream ss;
-            ss.str( s );
+            ss.str(s);
             Tag item;
             item.Read<SwapperNoOp>(ss);
             assert( item == itemPMSStart );
             ss.seekg(-4,std::ios::cur);
             sqi->Read<ExplicitDataElement,SwapperDoOp>( ss );
+            (void)ex;//cast to avoid the warning message
             }
           return sqi;
           }
@@ -128,9 +128,25 @@ namespace gdcm
           assert( bv );
           SequenceOfItems *sqi = new SequenceOfItems;
           sqi->SetLength( bv->GetLength() );
-          std::stringstream ss;
-          ss.str( std::string( bv->GetPointer(), bv->GetLength() ) );
-          sqi->Read<ImplicitDataElement,SwapperNoOp>( ss );
+          std::string s( bv->GetPointer(), bv->GetLength() );
+          try
+            {
+            std::stringstream ss;
+            ss.str( s );
+            sqi->Read<ImplicitDataElement,SwapperNoOp>( ss );
+            }
+          catch ( Exception &ex )
+            {
+            // Some people like to skew things up and write invalid SQ in VR:UN field
+            // if conversion fails, simply keep the binary VR:UN stuff as-is
+            // eg. AMIInvalidPrivateDefinedLengthSQasUN.dcm";
+            //const char *s = e.what();
+            // s -> gdcm::ImplicitDataElement -> Impossible (more)
+            std::stringstream ss;
+            ss.str(s);
+            sqi->Read<ExplicitDataElement,SwapperDoOp>( ss );
+            (void)ex;//cast to avoid the warning message
+            }
           return sqi;
           }
         else
@@ -158,4 +174,3 @@ namespace gdcm
     }
 
 } // end namespace gdcm
-
