@@ -41,7 +41,7 @@ class SequenceOfFragments;
  * either Implicit or Explicit
  *
  * \details
- * DATA ELEMENT: 
+ * DATA ELEMENT:
  * A unit of information as defined by a single entry in the data dictionary.
  * An encoded Information Object Definition (IOD) Attribute that is composed
  * of, at a minimum, three fields: a Data Element Tag, a Value Length, and a
@@ -232,6 +232,17 @@ public:
     return static_cast<TDE*>(this)->template Read<TSwap>(is);
   }
 
+  template <typename TDE, typename TSwap>
+  std::istream &ReadPreValue(std::istream &is, std::set<Tag> const &skiptags) {
+    (void)skiptags;
+    return static_cast<TDE*>(this)->template ReadPreValue<TSwap>(is);
+  }
+  template <typename TDE, typename TSwap>
+  std::istream &ReadValue(std::istream &is, std::set<Tag> const &skiptags) {
+    (void)skiptags;
+    return static_cast<TDE*>(this)->template ReadValue<TSwap>(is);
+  }
+
   template <typename TDE, typename TSwap>
   std::istream &ReadWithLength(std::istream &is, VL &length) {
     return static_cast<TDE*>(this)->template ReadWithLength<TSwap>(is,length);
@@ -268,4 +279,3 @@ inline std::ostream& operator<<(std::ostream &os, const DataElement &val)
 } // end namespace gdcm
 
 #endif //GDCMDATAELEMENT_H
-
