@@ -86,7 +86,11 @@ public:
   void SetFromDataElement(DataElement const &de) {
     const ByteValue *bv = de.GetByteValue();
     if( !bv ) return;
+#ifdef GDCM_WORDS_BIGENDIAN
+    if( de.GetVR() == VR::UN /*|| de.GetVR() == VR::INVALID*/ )
+#else
     if( de.GetVR() == VR::UN || de.GetVR() == VR::INVALID )
+#endif
       {
       Set(de.GetValue());
       }
@@ -97,11 +101,11 @@ public:
   }
 
   void Read(std::istream &_is) {
-    return EncodingImplementation<VRToEncoding<TVR>::Mode>::Read(Internal, 
+    return EncodingImplementation<VRToEncoding<TVR>::Mode>::Read(Internal,
       GetLength(),_is);
     }
   void Write(std::ostream &_os) const {
-    return EncodingImplementation<VRToEncoding<TVR>::Mode>::Write(Internal, 
+    return EncodingImplementation<VRToEncoding<TVR>::Mode>::Write(Internal,
       GetLength(),_os);
     }
 
@@ -109,13 +113,14 @@ public:
   // this is only used in gdcm::SplitMosaicFilter / to pass value of a CSAElement
   void Set(Value const &v) {
     const ByteValue *bv = dynamic_cast<const ByteValue*>(&v);
-    assert( bv ); // That would be bad...
-    //memcpy(Internal, bv->GetPointer(), bv->GetLength());
-    std::stringstream ss;
-    std::string s = std::string( bv->GetPointer(), bv->GetLength() );
-    ss.str( s );
-    EncodingImplementation<VRToEncoding<TVR>::Mode>::Read(Internal, 
-      GetLength(),ss);
+    if( bv ) {
+      //memcpy(Internal, bv->GetPointer(), bv->GetLength());
+      std::stringstream ss;
+      std::string s = std::string( bv->GetPointer(), bv->GetLength() );
+      ss.str( s );
+      EncodingImplementation<VRToEncoding<TVR>::Mode>::Read(Internal,
+        GetLength(),ss);
+    }
   }
 protected:
   void SetNoSwap(Value const &v) {
@@ -125,7 +130,7 @@ protected:
     std::stringstream ss;
     std::string s = std::string( bv->GetPointer(), bv->GetLength() );
     ss.str( s );
-    EncodingImplementation<VRToEncoding<TVR>::Mode>::ReadNoSwap(Internal, 
+    EncodingImplementation<VRToEncoding<TVR>::Mode>::ReadNoSwap(Internal,
       GetLength(),ss);
   }
 };
@@ -142,7 +147,7 @@ ignore_char const backslash('\\');
     if (in.get() != ic.m_char)
       in.setstate(std::ios_base::failbit);
     return in;
-  } 
+  }
 
 
 // Implementation to perform formatted read and write
@@ -224,7 +229,7 @@ std::string to_string ( Float data ) {
   } else {
     throw "Impossible Conversion"; // should not happen ...
   }
-} 
+}
 
 /* Writing VR::DS is not that easy after all */
 // http://groups.google.com/group/comp.lang.c++/browse_thread/thread/69ccd26f000a0802
@@ -254,7 +259,7 @@ template<> inline void EncodingImplementation<VR::VRASCII>::Write(const double*
 // Implementation to perform binary read and write
 // TODO rewrite operation so that either:
 // #1. dummy implementation use a pointer to Internal and do ++p (faster)
-// #2. Actually do some meta programming to unroll the loop 
+// #2. Actually do some meta programming to unroll the loop
 // (no notion of order in VM ...)
 template<> class EncodingImplementation<VR::VRBINARY> {
 public:
@@ -306,7 +311,7 @@ public:
   }
   template<typename T>
   static inline void Write(const T* data, unsigned long length,
-    std::ostream &_os) { 
+    std::ostream &_os) {
     const unsigned int type_size = sizeof(T);
     assert( data ); // Can we write into pointer ?
     assert( length );
@@ -326,7 +331,7 @@ public:
 };
 
 // For particular case for ASCII string
-// WARNING: This template explicitely instanciates a particular 
+// WARNING: This template explicitely instanciates a particular
 // EncodingImplementation THEREFORE it is required to be declared after the
 // EncodingImplementation is needs (doh!)
 #if 0
@@ -346,7 +351,7 @@ public:
       Internal[i++] = sarray.substr(pos1, pos2-pos1);
       pos1 = pos2+1;
       pos2 = sarray.find(sep, pos1+1);
-      } 
+      }
     Internal[i] = sarray.substr(pos1, pos2-pos1);
     // Shouldn't we do the contrary, since we know how many separators
     // (and default behavior is to discard anything after the VM declared
@@ -379,7 +384,7 @@ class Element<VR::PN, TVM> : public StringElement<TVM>
 };
 #endif
 
-// Implementation for the undefined length (dynamically allocated array) 
+// Implementation for the undefined length (dynamically allocated array)
 template<int TVR>
 class Element<TVR, VM::VM1_n>
 {
@@ -407,7 +412,7 @@ public:
         assert( (len / size) * size == len );
         Type *internal = new Type[len / size];
         assert( Save == false );
-        Save = true; // ???? 
+        Save = true; // ????
         if( Internal )
           {
           memcpy(internal, Internal, len);
@@ -420,7 +425,7 @@ public:
   }
 
   // If save is set to zero user should not delete the pointer
-  //void SetArray(const typename VRToType<TVR>::Type *array, int len, bool save = false) 
+  //void SetArray(const typename VRToType<TVR>::Type *array, int len, bool save = false)
   void SetArray(const Type *array, unsigned long len,
     bool save = false) {
     if( save ) {
@@ -477,6 +482,23 @@ public:
         GetLength(),ss);
       }
   }
+  void SetFromDataElement(DataElement const &de) {
+    const ByteValue *bv = de.GetByteValue();
+    if( !bv ) return;
+#ifdef GDCM_WORDS_BIGENDIAN
+    if( de.GetVR() == VR::UN /*|| de.GetVR() == VR::INVALID*/ )
+#else
+    if( de.GetVR() == VR::UN || de.GetVR() == VR::INVALID )
+#endif
+      {
+      Set(de.GetValue());
+      }
+    else
+      {
+      SetNoSwap(de.GetValue());
+      }
+  }
+
 
   // Need to be placed after definition of EncodingImplementation<VR::VRASCII>
   void WriteASCII(std::ostream &os) const {
@@ -494,16 +516,16 @@ public:
     }
   void Read(std::istream &_is) {
     if( !Internal ) return;
-    EncodingImplementation<VRToEncoding<TVR>::Mode>::Read(Internal, 
+    EncodingImplementation<VRToEncoding<TVR>::Mode>::Read(Internal,
       GetLength(),_is);
     }
   //void ReadComputeLength(std::istream &_is) {
   //  if( !Internal ) return;
-  //  EncodingImplementation<VRToEncoding<TVR>::Mode>::ReadComputeLength(Internal, 
+  //  EncodingImplementation<VRToEncoding<TVR>::Mode>::ReadComputeLength(Internal,
   //    Length,_is);
   //  }
   void Write(std::ostream &_os) const {
-    EncodingImplementation<VRToEncoding<TVR>::Mode>::Write(Internal, 
+    EncodingImplementation<VRToEncoding<TVR>::Mode>::Write(Internal,
       GetLength(),_os);
     }
 
@@ -513,7 +535,7 @@ public:
     if( Internal )
       {
       std::ostringstream os;
-      EncodingImplementation<VRToEncoding<TVR>::Mode>::Write(Internal, 
+      EncodingImplementation<VRToEncoding<TVR>::Mode>::Write(Internal,
         GetLength(),os);
       ret.SetByteValue( os.str().c_str(), os.str().size() );
       }
@@ -532,6 +554,27 @@ public:
     SetArray(_val.Internal, _val.Length, true);
     return *this;
     }
+protected:
+  void SetNoSwap(Value const &v) {
+    const ByteValue *bv = dynamic_cast<const ByteValue*>(&v);
+    assert( bv ); // That would be bad...
+    if( (VR::VRType)(VRToEncoding<TVR>::Mode) == VR::VRBINARY )
+      {
+      const Type* array = (Type*)bv->GetPointer();
+      if( array ) {
+        assert( array ); // That would be bad...
+        assert( Internal == 0 );
+        SetArray(array, bv->GetLength() ); }
+      }
+    else
+      {
+      std::stringstream ss;
+      std::string s = std::string( bv->GetPointer(), bv->GetLength() );
+      ss.str( s );
+      EncodingImplementation<VRToEncoding<TVR>::Mode>::ReadNoSwap(Internal,
+        GetLength(),ss);
+      }
+  }
 
 private:
   typename VRToType<TVR>::Type *Internal;
