@@ -31,6 +31,12 @@ public:
   template <typename TSwap>
   std::istream &Read(std::istream &is);
 
+  template <typename TSwap>
+  std::istream &ReadPreValue(std::istream &is);
+
+  template <typename TSwap>
+  std::istream &ReadValue(std::istream &is);
+
   template <typename TSwap>
   std::istream &ReadWithLength(std::istream &is, VL & length);
 
@@ -43,4 +49,3 @@ public:
 #include "gdcmExplicitDataElement.txx"
 
 #endif //GDCMEXPLICITDATAELEMENT_H
-
