@@ -35,11 +35,17 @@ public:
   template <typename TSwap>
   std::istream &Read(std::istream &is);
 
-template <typename TSwap>
-std::istream &ReadWithLength(std::istream &is, VL & length)
-{
-  return Read<TSwap>(is); (void)length;
-}
+  template <typename TSwap>
+  std::istream &ReadPreValue(std::istream &is);
+
+  template <typename TSwap>
+  std::istream &ReadValue(std::istream &is);
+
+  template <typename TSwap>
+  std::istream &ReadWithLength(std::istream &is, VL & length)
+    {
+    return Read<TSwap>(is); (void)length;
+    }
 
   // PURPOSELY do not provide an implementation for writing !
   //template <typename TSwap>
@@ -51,4 +57,3 @@ std::istream &ReadWithLength(std::istream &is, VL & length)
 #include "gdcmExplicitImplicitDataElement.txx"
 
 #endif //GDCMEXPLICITIMPLICITDATAELEMENT_H
-
