@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,15 +12,14 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmImplicitDataElement_h
-#define __gdcmImplicitDataElement_h
+#ifndef GDCMIMPLICITDATAELEMENT_H
+#define GDCMIMPLICITDATAELEMENT_H
 
 #include "gdcmDataElement.h"
 
 namespace gdcm
 {
 
-class ExplicitImplicitDataElement;
 /**
  * \brief Class to represent an *Implicit VR* Data Element
  * \note bla
@@ -33,6 +32,12 @@ public:
   template <typename TSwap>
   std::istream &Read(std::istream& is);
 
+  template <typename TSwap>
+  std::istream &ReadPreValue(std::istream& is);
+
+  template <typename TSwap>
+  std::istream &ReadValue(std::istream& is);
+
   template <typename TSwap>
   std::istream &ReadWithLength(std::istream& is, VL & length);
 
@@ -44,4 +49,4 @@ public:
 
 #include "gdcmImplicitDataElement.txx"
 
-#endif //__gdcmImplicitDataElement_h
+#endif //GDCMIMPLICITDATAELEMENT_H
