@@ -20,9 +20,11 @@
 
 #include <iostream>
 #include <iomanip>
+#include <string>
 #include <algorithm>
 
 #include <string.h> // strlen
+#include <ctype.h> // tolower
 
 namespace gdcm
 {
@@ -37,8 +39,13 @@ class GDCM_EXPORT PrivateTag : public Tag
   friend std::ostream& operator<<(std::ostream &_os, const PrivateTag &_val);
 public:
   PrivateTag(uint16_t group = 0, uint16_t element = 0, const char *owner = ""):Tag(group,element),Owner(owner) {
-    std::transform(Owner.begin(), Owner.end(), Owner.begin(), tolower);
-    //assert( element > 0x0010 && element < 0x100 );
+    std::transform(Owner.begin(), Owner.end(), Owner.begin(), ::tolower);
+    // truncate the high bits
+    SetElement( (uint8_t)element );
+
+    // TODO:
+    // by default the cstor create with 0x0,0x0 which is invalid...
+    //assert( GetElement() >= 0x0010 && GetElement() < 0x100 );
   }
 
   const char *GetOwner() const { return Owner.c_str(); }
@@ -93,4 +100,3 @@ inline std::ostream& operator<<(std::ostream &os, const PrivateTag &val)
 } // end namespace gdcm
 
 #endif //GDCMPRIVATETAG_H
-
