@@ -37,10 +37,13 @@ namespace gdcm
 
 Reader::~Reader()
 {
-  if (Ifstream) {
+  if (Ifstream)
+    {
     Ifstream->close();
     delete Ifstream;
-  }
+    Ifstream = NULL;
+    Stream = NULL;
+    }
 }
 
 /// \brief tells us if "DICM" is found as position 128
@@ -208,13 +211,14 @@ namespace details
         {
         m_dataSet.template ReadWithLength<T1,T2>(is,length);
         }
-    static void Check(bool b, std::istream &stream) 
+    static void Check(bool b, std::istream &stream)
       {
+      (void)stream;
       if( b ) assert( stream.eof() );
       }
   };
 
-  class ReadUpToTagCaller 
+  class ReadUpToTagCaller
   {
   private:
     gdcm::DataSet & m_dataSet;
@@ -238,9 +242,9 @@ namespace details
         m_dataSet.template ReadUpToTagWithLength<T1,T2>(is,m_tag,length);
         }
     static void Check(bool , std::istream &)  {}
-  }; 
+  };
 
-  class ReadSelectedTagsCaller 
+  class ReadSelectedTagsCaller
   {
   private:
     DataSet & m_dataSet;
@@ -263,7 +267,7 @@ namespace details
       m_dataSet.template ReadSelectedTagsWithLength<T1,T2>(is,m_tags,length);
     }
     static void Check(bool , std::istream &)  {}
-  }; 
+  };
 }
 
 bool Reader::Read()
@@ -294,81 +298,81 @@ bool Reader::InternalReadCommon(const T_Caller &caller)
     }
   bool success = true;
 
-try
-    {
-std::istream &is = *Stream;
-
-  bool haspreamble = true;
   try
     {
-    F->GetHeader().GetPreamble().Read( is );
-    }
-  catch( std::exception &ex )
-    {
-    // return to beginning of file, hopefully this file is simply missing preamble
-    is.seekg(0, std::ios::beg);
-    haspreamble = false;
-    }
-  catch( ... )
-    {
-    assert(0);
-    }
+    std::istream &is = *Stream;
 
-  bool hasmetaheader = false;
-  try
-    {
-    if( haspreamble )
+    bool haspreamble = true;
+    try
       {
-      try
+      F->GetHeader().GetPreamble().Read( is );
+      }
+    catch( std::exception &ex )
+      {
+      // return to beginning of file, hopefully this file is simply missing preamble
+      is.seekg(0, std::ios::beg);
+      haspreamble = false;
+      }
+    catch( ... )
+      {
+      assert(0);
+      }
+
+    bool hasmetaheader = false;
+    try
+      {
+      if( haspreamble )
         {
-        F->GetHeader().Read( is );
-        hasmetaheader = true;
-        assert( !F->GetHeader().IsEmpty() );
-        }
-      catch( std::exception &ex )
-        {
-        (void)ex;
-        // Weird implicit meta header:
-        is.seekg(128+4, std::ios::beg );
         try
           {
-          F->GetHeader().ReadCompat(is);
+          F->GetHeader().Read( is );
+          hasmetaheader = true;
+          assert( !F->GetHeader().IsEmpty() );
           }
-        catch( std::exception &ex2 )
+        catch( std::exception &ex )
           {
-          // Ok I get it now... there is absolutely no meta header, giving up
-          //hasmetaheader = false;
-          (void)ex2;
+          (void)ex;
+          // Weird implicit meta header:
+          is.seekg(128+4, std::ios::beg );
+          try
+            {
+            F->GetHeader().ReadCompat(is);
+            }
+          catch( std::exception &ex2 )
+            {
+            // Ok I get it now... there is absolutely no meta header, giving up
+            //hasmetaheader = false;
+            (void)ex2;
+            }
           }
         }
+      else
+        {
+        F->GetHeader().ReadCompat(is);
+        }
       }
-    else
+    catch( std::exception &ex )
       {
-      F->GetHeader().ReadCompat(is);
+      // Same player play again:
+      is.seekg(0, std::ios::beg );
+      hasmetaheader = false;
+      }
+    catch( ... )
+      {
+      // Ooops..
+      assert(0);
+      }
+    if( F->GetHeader().IsEmpty() )
+      {
+      hasmetaheader = false;
+      gdcmDebugMacro( "no file meta info found" );
       }
-    }
-  catch( std::exception &ex )
-    {
-    // Same player play again:
-    is.seekg(0, std::ios::beg );
-    hasmetaheader = false;
-    }
-  catch( ... )
-    {
-    // Ooops..
-    assert(0);
-    }
-  if( F->GetHeader().IsEmpty() )
-    {
-    hasmetaheader = false;
-    gdcmWarningMacro( "no file meta info found" );
-    }
 
-  const TransferSyntax &ts = F->GetHeader().GetDataSetTransferSyntax();
-  if( !ts.IsValid() )
-    {
-    throw Exception( "Meta Header issue" );
-    }
+    const TransferSyntax &ts = F->GetHeader().GetDataSetTransferSyntax();
+    if( !ts.IsValid() )
+      {
+      throw Exception( "Meta Header issue" );
+      }
 
   //std::cerr << ts.GetNegociatedType() << std::endl;
   //std::cerr << TransferSyntax::GetTSString(ts) << std::endl;
@@ -403,6 +407,7 @@ std::istream &is = *Stream;
         // There is no such thing as Implicit Big Endian... oh well
         // LIBIDO-16-ACR_NEMA-Volume.dcm
         //F->GetDataSet().ReadUpToTag<ImplicitDataElement,SwapperDoOp>(is,tag, skiptags);
+        //caller.template ReadCommon<ImplicitDataElement,SwapperDoOp>(is);
         throw "Virtual Big Endian Implicit is not defined by DICOM";
         }
       else
@@ -578,6 +583,13 @@ std::istream &is = *Stream;
           catch ( Exception &ex2 )
             {
             (void)ex2;
+            // Mon Jan 24 10:59:25 CET 2011
+            // MM: UNExplicitImplicitDataElement does not seems to be used anymore to read
+            // gdcmData/TheralysGDCM120Bug.dcm, instead the code path goes into
+            // ExplicitImplicitDataElement class instead.
+            // Simply rethrow the exception for now.
+            throw;
+#if 0
             is.clear();
             if( haspreamble )
               {
@@ -600,13 +612,14 @@ std::istream &is = *Stream;
             F->GetDataSet().Clear(); // remove garbage from 1st attempt...
             //F->GetDataSet().template Read<UNExplicitImplicitDataElement,SwapperNoOp>(is);
             caller.template ReadCommon<UNExplicitImplicitDataElement,SwapperNoOp>(is);
+#endif
             }
           }
         }
       }
     else
       {
-        gdcmWarningMacro( "Attempt to read the file as mixture of explicit/implicit");
+      gdcmWarningMacro( "Attempt to read the file as mixture of explicit/implicit");
       // Let's try again with an ExplicitImplicitDataElement:
       if( ts.GetSwapCode() == SwapCode::LittleEndian &&
         ts.GetNegociatedType() == TransferSyntax::Explicit )
@@ -651,8 +664,8 @@ std::istream &is = *Stream;
     success = false;
     }
 
-    //if( success ) assert( Stream->eof() );
-    caller.Check(success, *Stream );
+  //if( success ) assert( Stream->eof() );
+  caller.Check(success, *Stream );
     }
   catch( Exception &ex )
     {
@@ -664,19 +677,19 @@ std::istream &is = *Stream;
     gdcmWarningMacro( "Unknown exception" );
     success = false;
     }
-//  if( !success )
-//    {
-//    F->GetHeader().Clear();
-//    F->GetDataSet().Clear();
-//    }
+  //  if( !success )
+  //    {
+  //    F->GetHeader().Clear();
+  //    F->GetDataSet().Clear();
+  //    }
 
   // FIXME : call this function twice...
   if (Ifstream && Ifstream->is_open())
     {
-    Ifstream->close();
-    delete Ifstream;
-    Ifstream = NULL;
-    Stream = NULL;
+    //Ifstream->close();
+    //delete Ifstream;
+    //Ifstream = NULL;
+    //Stream = NULL;
     }
 
   return success;
