@@ -32,6 +32,12 @@ public:
   template <typename TSwap>
   std::istream &Read(std::istream &is);
 
+  template <typename TSwap>
+  std::istream &ReadPreValue(std::istream &is);
+
+  template <typename TSwap>
+  std::istream &ReadValue(std::istream &is);
+
   template <typename TSwap>
   std::istream &ReadWithLength(std::istream &is, VL & length);
 
@@ -45,4 +51,3 @@ public:
 #include "gdcmUNExplicitDataElement.txx"
 
 #endif //GDCMUNEXPLICITDATAELEMENT_H
-
