@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -340,6 +340,7 @@ VM::VMType VM::GetVMTypeFromLength(unsigned int length, unsigned int size)
   case 5: return VM::VM5;
   case 6: return VM::VM6;
   case 8: return VM::VM8;
+  case 9: return VM::VM9;
   case 16: return VM::VM16;
   case 24: return VM::VM24;
   case 32: return VM::VM32;
@@ -390,19 +391,19 @@ bool VM::Compatible(VM const &vm) const
   switch(VMField)
     {
   case VM1_2:
-    r = vm.VMField >= VM::VM1 || vm.VMField <= VM::VM2;
+    r = vm.VMField >= VM::VM1 && vm.VMField <= VM::VM2;
     break;
   case VM1_3:
-    r = vm.VMField >= VM::VM1 || vm.VMField <= VM::VM3;
+    r = vm.VMField >= VM::VM1 && vm.VMField <= VM::VM3;
     break;
   case VM1_8:
-    r = vm.VMField >= VM::VM1 || vm.VMField <= VM::VM8;
+    r = vm.VMField >= VM::VM1 && vm.VMField <= VM::VM8;
     break;
   case VM1_32:
-    r = vm.VMField >= VM::VM1 || vm.VMField <= VM::VM32;
+    r = vm.VMField >= VM::VM1 && vm.VMField <= VM::VM32;
     break;
   case VM1_99:
-    r = vm.VMField >= VM::VM1 || vm.VMField <= VM::VM99;
+    r = vm.VMField >= VM::VM1 && vm.VMField <= VM::VM99;
     break;
   case VM1_n:
     r = vm.VMField >= VM::VM1;
@@ -420,7 +421,7 @@ bool VM::Compatible(VM const &vm) const
     r = vm.VMField == VM::VM3 || vm.VMField == VM::VM4;
     break;
   case VM3_3n:
-    r = vm.VMField >= VM::VM3 /*&& !(vm.GetLength() % 3)*/;
+    r = vm.VMField >= VM::VM3 && !(vm.GetLength() % 3);
     break;
   case VM3_n:
     r = vm.VMField >= VM::VM3;
@@ -428,7 +429,10 @@ bool VM::Compatible(VM const &vm) const
   default:
     r = VMField == vm.VMField;
     }
-  if( r ) assert( VMField & vm.VMField );
+  if( r )
+    {
+    assert( VMField & vm.VMField );
+    }
   return r;
 }
 
