@@ -34,6 +34,12 @@ public:
   template <typename TSwap>
   std::istream &Read(std::istream &is);
 
+  template <typename TSwap>
+  std::istream &ReadPreValue(std::istream &is);
+
+  template <typename TSwap>
+  std::istream &ReadValue(std::istream &is);
+
   template <typename TSwap>
   std::istream &ReadWithLength(std::istream &is, VL & length);
 
@@ -47,4 +53,3 @@ public:
 #include "gdcmVR16ExplicitDataElement.txx"
 
 #endif //GDCMVR16EXPLICITDATAELEMENT_H
-
