@@ -28,7 +28,7 @@ class FileMetaInformation;
  * formedness check only.
  *
  * \details Detailled description here
- * To avoid GDCM being yet another broken DICOM lib we try to 
+ * To avoid GDCM being yet another broken DICOM lib we try to
  * be user level and avoid writing illegal stuff (odd length,
  * non-zero value for Item start/end length ...)
  * Therefore you cannot (well unless you are really smart) write
@@ -41,17 +41,15 @@ class FileMetaInformation;
  * - 32bits VR will be rewritten with 00
  *
  * \warning
- * gdcm::Writer cannot write a DataSet if no SOP Instance UID (0008,0018) is found
+ * gdcm::Writer cannot write a DataSet if no SOP Instance UID (0008,0018) is found,
+ * unless a DICOMDIR is being written out
  *
  * \see Reader DataSet File
  */
 class GDCM_EXPORT Writer
 {
 public:
-  Writer():F(new File),CheckFileMetaInformation(true) {
-	  Stream = NULL;
-	  Ofstream = NULL;
-  }
+  Writer();
   virtual ~Writer();
 
   /// Main function to tell the writer to write
@@ -87,6 +85,13 @@ public:
   void CheckFileMetaInformationOff() { CheckFileMetaInformation = false; }
   void CheckFileMetaInformationOn() { CheckFileMetaInformation = true; }
 
+protected:
+  friend class StreamImageWriter;
+  //this function is added for the StreamImageWriter, which needs to write
+  //up to the pixel data and then stops right before writing the pixel data.
+  //after that, for the raw codec at least, zeros are written for the length of the data
+  std::ostream* GetStreamPtr() const { return Stream; }
+
 protected:
   std::ostream *Stream;
   std::ofstream *Ofstream;
