@@ -106,10 +106,11 @@ bool Anonymizer::Remove( Tag const &t )
 
 bool Anonymizer::Replace( Tag const &t, const char *value )
 {
-  size_t len = 0;
+  VL::Type len = 0; //to avoid the size_t warning on 64 bit windows
   if( value )
     {
-    len = strlen( value );
+    len = (VL::Type)strlen( value );//strlen returns size_t, but it should be VL::Type
+    //strlen shouldn't be more than 4gb anyway
     }
   return Replace( t, value, len );
 }
@@ -155,8 +156,8 @@ bool Anonymizer::Replace( Tag const &t, const char *value, VL const & vl )
     // Ok this is a public element
     assert( t.IsPublic() );
     const DictEntry &dictentry = dicts.GetDictEntry(t);
-    if ( dictentry.GetVR() == VR::INVALID 
-      || dictentry.GetVR() == VR::UN 
+    if ( dictentry.GetVR() == VR::INVALID
+      || dictentry.GetVR() == VR::UN
       || dictentry.GetVR() == VR::SQ
     )
       {
@@ -245,7 +246,8 @@ bool Anonymizer::Replace( Tag const &t, const char *value, VL const & vl )
           {
           de.SetVR( dictentry.GetVR() );
           }
-        de.SetByteValue( padded.c_str(), padded.size() );
+        const VL::Type paddedSize = (VL::Type) padded.size();//casting to avoid size_t warning on 64
+        de.SetByteValue( padded.c_str(), paddedSize );
         ds.Replace( de );
         ret = true;
         }
@@ -283,8 +285,8 @@ static bool Anonymizer_RemoveRetired(File const &file, DataSet &ds)
         SmartPointer<SequenceOfItems> sq = de.GetValueAsSQ();
         if( sq )
           {
-          unsigned int n = sq->GetNumberOfItems();
-          for( unsigned int i = 1; i <= n; i++) // item starts at 1, not 0
+          gdcm::SequenceOfItems::SizeType n = sq->GetNumberOfItems();
+          for( gdcm::SequenceOfItems::SizeType i = 1; i <= n; i++) // item starts at 1, not 0
             {
             Item &item = sq->GetItem( i );
             DataSet &nested = item.GetNestedDataSet();
@@ -329,8 +331,8 @@ static bool Anonymizer_RemoveGroupLength(File const &file, DataSet &ds)
         SmartPointer<SequenceOfItems> sq = de.GetValueAsSQ();
         if( sq )
           {
-          unsigned int n = sq->GetNumberOfItems();
-          for( unsigned int i = 1; i <= n; i++) // item starts at 1, not 0
+          gdcm::SequenceOfItems::SizeType n = sq->GetNumberOfItems();
+          for( gdcm::SequenceOfItems::SizeType i = 1; i <= n; i++) // item starts at 1, not 0
             {
             Item &item = sq->GetItem( i );
             DataSet &nested = item.GetNestedDataSet();
@@ -375,8 +377,8 @@ static bool Anonymizer_RemovePrivateTags(File const &file, DataSet &ds)
         SmartPointer<SequenceOfItems> sq = de.GetValueAsSQ();
         if( sq )
           {
-          unsigned int n = sq->GetNumberOfItems();
-          for( unsigned int i = 1; i <= n; i++) // item starts at 1, not 0
+          gdcm::SequenceOfItems::SizeType n = sq->GetNumberOfItems();
+          for( gdcm::SequenceOfItems::SizeType i = 1; i <= n; i++) // item starts at 1, not 0
             {
             Item &item = sq->GetItem( i );
             DataSet &nested = item.GetNestedDataSet();
@@ -446,8 +448,8 @@ bool Anonymizer::CheckIfSequenceContainsAttributeToAnonymize(File const &file, S
   if( found ) return true;
 
   // now look into sub-sequence:
-  unsigned int n = sqi->GetNumberOfItems();
-  for( unsigned int i = 1; i <= n; i++) // item starts at 1, not 0
+  gdcm::SequenceOfItems::SizeType n = sqi->GetNumberOfItems();
+  for( gdcm::SequenceOfItems::SizeType i = 1; i <= n; i++) // item starts at 1, not 0
     {
     Item &item = sqi->GetItem( i );
     DataSet &nested = item.GetNestedDataSet();
@@ -488,13 +490,20 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile1()
   //p7.SetCertificate( this->x509 );
 
   DataSet &ds = F->GetDataSet();
-  if(  ds.FindDataElement( Tag(0x0400,0x0500) ) 
-    || ds.FindDataElement( Tag(0x0012,0x0062) ) 
+  if(  ds.FindDataElement( Tag(0x0400,0x0500) )
+    || ds.FindDataElement( Tag(0x0012,0x0062) )
     || ds.FindDataElement( Tag(0x0012,0x0063) ) )
     {
     gdcmDebugMacro( "EncryptedContentTransferSyntax Attribute is present !" );
     return false;
     }
+#if 0
+  if( !ds.FindDataElement( Tag(0x0008,0x0018) )
+    || ds.GetDataElement( Tag(0x0008,0x0018) ).IsEmpty() )
+    {
+    return false;
+    }
+#endif
 
   // PS 3.15
   // E.1 BASIC APPLICATION LEVEL CONFIDENTIALITY PROFILE
@@ -590,12 +599,15 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile1()
 
   size_t encrypted_len2 = encrypted_len;
   bool b = p7.Encrypt( buf, encrypted_len, orig, encrypted_str.size() );
-  if( !b ) 
+  if( !b )
   {
+    delete[] orig;
+    delete[] buf;
     gdcmErrorMacro( "Problem with Encrypt" );
     return false;
   }
   assert( encrypted_len <= encrypted_len2 );
+  (void)encrypted_len2;//warning removal
 
     {
     // Create a Sequence
@@ -608,11 +620,13 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile1()
     // <entry group="0400" element="0510" vr="UI" vm="1" name="Encrypted Content Transfer Syntax UID"/>
     DataElement encrypted_ts_de( Tag(0x400,0x510) );
     encrypted_ts_de.SetVR( Attribute<0x0400, 0x0510>::GetVR() );
-    encrypted_ts_de.SetByteValue( encrypted_ts.GetString(), strlen(encrypted_ts.GetString()) );
+    const VL::Type encryptedStrLen = (VL::Type)strlen(encrypted_ts.GetString());
+    encrypted_ts_de.SetByteValue( encrypted_ts.GetString(), encryptedStrLen );
     // <entry group="0400" element="0520" vr="OB" vm="1" name="Encrypted Content"/>
     DataElement encrypted_de( Tag(0x400,0x520) );
     encrypted_de.SetVR( Attribute<0x0400, 0x0520>::GetVR() );
-    encrypted_de.SetByteValue( (char*)buf, encrypted_len );
+    const VL::Type encryptedLenSize = (VL::Type)encrypted_len;
+    encrypted_de.SetByteValue( (char*)buf, encryptedLenSize );
     delete[] buf;
     delete[] orig;
 
@@ -667,7 +681,8 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile1()
   }
   catch(std::exception &ex)
   {
-  gdcmDebugMacro( "Problem during RecurseDataSet" );
+  gdcmDebugMacro( "Problem during RecurseDataSet");
+  (void)ex; //to get rid of the warning.  TODO: spit out the exception
   return false;
   }
 catch(...)
@@ -692,13 +707,18 @@ catch(...)
 
   this->InvokeEvent( IterationEvent() );
 
-  // Since the de-identified SOP Instance is a significantly altered version of the original Data Set, it is
-  // a new SOP Instance, with a SOP Instance UID that differs from the original Data Set.
+#if 0
+  // Since the de-identified SOP Instance is a significantly altered version of
+  // the original Data Set, it is a new SOP Instance, with a SOP Instance UID
+  // that differs from the original Data Set.
   UIDGenerator uid;
-  if( ds.FindDataElement( Tag(0x008,0x0018) ) )
+  if( ds.FindDataElement( Tag(0x0008,0x0018) ) )
+    {
     Replace( Tag(0x008,0x0018), uid.Generate() );
+    }
 
   this->InvokeEvent( IterationEvent() );
+#endif
 
   return true;
 }
@@ -711,7 +731,7 @@ bool IsVRUI(Tag const &tag)
   const DictEntry &dictentry = dicts.GetDictEntry(tag);
   if( dictentry.GetVR() == VR::UI ) return true;
   //if( tag == Tag(0x0020,0x000d)   // Study Instance UID : UI
-  // || tag == Tag(0x0020,0x0052)   // 
+  // || tag == Tag(0x0020,0x0052)   //
   // || tag == Tag(0x0020,0x000e) ) // Series Instance UID : UI
   //  {
   //  return true;
@@ -767,7 +787,7 @@ I think it would also make sense to quote the following attributes:
 * Study ID,
 * Series Number.
 It is required they have consistent values when one is about to
-generate a DICOMDIR 
+generate a DICOMDIR
 
 => Sup 142
 */
@@ -775,7 +795,7 @@ generate a DICOMDIR
   static const unsigned int numDeIds = sizeof(SpecialTypeTags) / deidSize;
 
   bool b = std::binary_search(SpecialTypeTags, SpecialTypeTags + numDeIds, tag);
-  
+
   // This is a Type 3 attribute but with VR=UI
   // <entry group="0008" element="0014" vr="UI" vm="1" name="Instance Creator UID"/>
   //assert( dicts.GetDictEntry(tag).GetVR() != VR::UI );
@@ -792,50 +812,74 @@ bool Anonymizer::BALCPProtect(DataSet &ds, Tag const & tag, IOD const & iod)
   this->InvokeEvent( ae );
 
   typedef std::pair< Tag, std::string > TagValueKey;
-  typedef std::map< TagValueKey, std::string > DummyMap;
-  static DummyMap dummymap;
-  gdcm::UIDGenerator uid;
-
-  //DataSet &ds = F->GetDataSet();
+  typedef std::map< TagValueKey, std::string > DummyMapNonUIDTags;
+  typedef std::map< std::string, std::string > DummyMapUIDTags;
+  static DummyMapNonUIDTags dummyMapNonUIDTags;
+  static DummyMapUIDTags dummyMapUIDTags;
 
   bool canempty = CanEmptyTag( tag, iod );
   if( !canempty )
     {
-    TagValueKey tvk;
-    tvk.first = tag;
     DataElement copy;
     copy = ds.GetDataElement( tag );
-    // gdcmData/LEADTOOLS_FLOWERS-16-MONO2-JpegLossless.dcm
-    // has an empty 0008,0018 attribute, let's try to handle that:
-    if( !copy.IsEmpty() )
+
+    if ( IsVRUI( tag ) )
       {
-      if( ByteValue *bv = copy.GetByteValue() )
+      std::string UIDToAnonymize = "";
+      gdcm::UIDGenerator uid;
+
+      if( !copy.IsEmpty() )
         {
-        tvk.second = std::string( bv->GetPointer(), bv->GetLength() );
+        if( ByteValue *bv = copy.GetByteValue() )
+          {
+          UIDToAnonymize = std::string( bv->GetPointer(), bv->GetLength() );
+          }
         }
-      }
-    assert( dummymap.count( tvk ) == 0 || dummymap.count( tvk ) == 1 );
-    if( dummymap.count( tvk ) == 0 )
-      {
-      // Generate a new (single) dummy value:
-      if( IsVRUI( tag ) )
+
+      std::string anonymizedUID = "";
+      if( !UIDToAnonymize.empty() )
         {
-        dummymap[ tvk ] = uid.Generate();
+        if ( dummyMapUIDTags.count( UIDToAnonymize ) == 0 )
+          {
+          anonymizedUID = uid.Generate();
+          dummyMapUIDTags[ UIDToAnonymize ] = anonymizedUID;
+          }
+        else
+          {
+          anonymizedUID = dummyMapUIDTags[ UIDToAnonymize ];
+          }
         }
       else
+        {
+        // gdcmData/LEADTOOLS_FLOWERS-16-MONO2-JpegLossless.dcm
+        // has an empty 0008,0018 attribute, let's try to handle creating new UID
+        anonymizedUID = uid.Generate();
+        }
+
+        copy.SetByteValue( anonymizedUID.c_str(), anonymizedUID.size() );
+        ds.Replace( copy );
+      }
+    else
+      {
+      TagValueKey tvk;
+      tvk.first = tag;
+
+      assert( dummyMapNonUIDTags.count( tvk ) == 0 || dummyMapNonUIDTags.count( tvk ) == 1 );
+      if( dummyMapNonUIDTags.count( tvk ) == 0 )
         {
         const char *ret = DummyValueGenerator::Generate( tvk.second.c_str() );
         if( ret )
           {
-          dummymap[ tvk ] = ret;
+          dummyMapNonUIDTags[ tvk ] = ret;
           }
         else
-          dummymap[ tvk ] = "";
+          dummyMapNonUIDTags[ tvk ] = "";
         }
+
+      std::string &v = dummyMapNonUIDTags[ tvk ];
+      copy.SetByteValue( v.c_str(), v.size() );
       }
-    std::string &v = dummymap[ tvk ];
-    copy.SetByteValue( v.c_str(), v.size() );
-    ds.Replace( copy );
+      ds.Replace( copy );
     }
   else
     {
@@ -889,8 +933,8 @@ void Anonymizer::RecurseDataSet( DataSet & ds )
       assert( sqi->IsUndefinedLength() );
       //de.GetVL().SetToUndefined();
       //sqi->SetLengthToUndefined();
-      unsigned int n = sqi->GetNumberOfItems();
-      for( unsigned int i = 1; i <= n; ++i )
+      gdcm::SequenceOfItems::SizeType n = sqi->GetNumberOfItems();
+      for( gdcm::SequenceOfItems::SizeType i = 1; i <= n; ++i )
         {
         Item &item = sqi->GetItem( i );
         DataSet &nested = item.GetNestedDataSet();
@@ -914,11 +958,13 @@ void Anonymizer::RecurseDataSet( DataSet & ds )
 
 bool Anonymizer::BasicApplicationLevelConfidentialityProfile2()
 {
-  // 1. The application shall decrypt, using its recipient key, one instance of the Encrypted Content
-  // (0400,0520) Attribute within the Encrypted Attributes Sequence (0400,0500) and decode the resulting
-  // block of bytes into a DICOM dataset using the Transfer Syntax specified in the Encrypted Content
-  // Transfer Syntax UID (0400,0510). Re-identifiers claiming conformance to this profile shall be capable
-  // of decrypting the Encrypted Content using either AES or Triple-DES in all possible key lengths
+  // 1. The application shall decrypt, using its recipient key, one instance of
+  // the Encrypted Content (0400,0520) Attribute within the Encrypted
+  // Attributes Sequence (0400,0500) and decode the resulting block of bytes
+  // into a DICOM dataset using the Transfer Syntax specified in the Encrypted
+  // Content Transfer Syntax UID (0400,0510). Re-identifiers claiming
+  // conformance to this profile shall be capable of decrypting the Encrypted
+  // Content using either AES or Triple-DES in all possible key lengths
   // specified in this profile
   CryptographicMessageSyntax &p7 = *CMS;
   //p7.SetCertificate( this->x509 );
@@ -934,7 +980,7 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile2()
   SmartPointer<SequenceOfItems> sq = EncryptedAttributesSequence.GetValueAsSQ();
   const Item &item1 = sq->GetItem(1);
   const DataSet &nds1 = item1.GetNestedDataSet();
-  if( !nds1.FindDataElement( Tag(0x0400,0x0510) ) 
+  if( !nds1.FindDataElement( Tag(0x0400,0x0510) )
     || nds1.GetDataElement( Tag(0x0400,0x0510) ).IsEmpty() )
     {
     gdcmDebugMacro( "Missing EncryptedContentTransferSyntax Attribute" );
@@ -952,7 +998,7 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile2()
     return false;
     }
 
-  if( !nds1.FindDataElement( Tag(0x0400,0x0520) ) 
+  if( !nds1.FindDataElement( Tag(0x0400,0x0520) )
     || nds1.GetDataElement( Tag(0x0400,0x0520) ).IsEmpty() )
     {
     gdcmDebugMacro( "Missing EncryptedContent Attribute" );
@@ -961,7 +1007,7 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile2()
 
   const DataElement &EncryptedContent = nds1.GetDataElement( Tag(0x0400,0x0520) );
   const ByteValue *bv = EncryptedContent.GetByteValue();
-  
+
   size_t encrypted_len = bv->GetLength();
   char *orig = new char[ bv->GetLength() ];
   char *buf = new char[ bv->GetLength() ];
@@ -976,6 +1022,7 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile2()
     return false;
     }
   assert( encrypted_len <= encrypted_len2 );
+  (void)encrypted_len2;//warning removal
 
   std::stringstream ss;
   ss.str( std::string((char*)buf, encrypted_len) );
@@ -997,17 +1044,18 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile2()
   //des.Read<ExplicitDataElement,SwapperNoOp>(ss);
   //des.ReadNested<ExplicitDataElement,SwapperNoOp>(ss);
 
-  //std::cout << des << std::endl; 
-  //std::cout << dummy << std::endl; 
-  //std::cout << ss.tellg() << std::endl; 
+  //std::cout << des << std::endl;
+  //std::cout << dummy << std::endl;
+  //std::cout << ss.tellg() << std::endl;
   assert( (size_t)ss.tellg() <= encrypted_len );
   // TODO: check that for i = ss.tellg() to encrypted_len, ss[i] == 0
   delete[] buf;
   delete[] orig;
 
-  // 2. The application shall move all Attributes contained in the single item of the Modified Attributes
-  // Sequence (0400,0550) of the decoded dataset into the main dataset, replacingdummy value
-  // Attributes that may be present in the main dataset.
+  // 2. The application shall move all Attributes contained in the single item
+  // of the Modified Attributes Sequence (0400,0550) of the decoded dataset
+  // into the main dataset, replacing dummy value Attributes that may be
+  // present in the main dataset.
   //assert( dummy.GetVR() == VR::SQ );
 {
   //const SequenceOfItems *sqi = dummy.GetSequenceOfItems();
@@ -1020,11 +1068,22 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile2()
     {
     ds.Replace( *it );
     }
+
+  // FIXME the above Replace assume that the encrypted content will replace
+  // any dummy values. What if the anonymizer was dumb and forgot
+  // to encrypt say UID 8,18 ? We would be left with the Instance UID
+  // of the encrypted one ?
+  if( !nds2.FindDataElement( Tag(0x8,0x18) ) )
+    {
+    gdcmErrorMacro( "Could not find Instance UID" );
+    return false;
+    }
 }
 
-  // 3. The attribute Patient Identity Removed (0012,0062) shall be replaced or added to the dataset with a
-  // value of NO and De-identification Method (0012,0063) and De-identification Method Code Sequence
-  // (0012,0064) shall be removed.
+  // 3. The attribute Patient Identity Removed (0012,0062) shall be replaced or
+  // added to the dataset with a value of NO and De-identification Method
+  // (0012,0063) and De-identification Method Code Sequence (0012,0064) shall
+  // be removed.
   //Replace( Tag(0x0012,0x0062), "NO");
   Remove( Tag(0x0012,0x0062) );
   Remove( Tag(0x0012,0x0063) );
@@ -1045,4 +1104,3 @@ const CryptographicMessageSyntax *Anonymizer::GetCryptographicMessageSyntax() co
 }
 
 } // end namespace gdcm
-
