@@ -95,7 +95,7 @@ void Bitmap::SetDimensions(const unsigned int *dims)
 {
   assert( NumberOfDimensions );
   //assert( Dimensions.empty() );
-  Dimensions = std::vector<unsigned int>(dims, 
+  Dimensions = std::vector<unsigned int>(dims,
     dims+NumberOfDimensions);
 }
 
@@ -107,7 +107,7 @@ void Bitmap::SetDimension(unsigned int idx, unsigned int dim)
   Dimensions.resize( 3 /*NumberOfDimensions*/ );
   // Can dim be 0 ??
   // -> no !
-  //assert( dim ); // PhilipsLosslessRice.dcm 
+  //assert( dim ); // PhilipsLosslessRice.dcm
   Dimensions[idx] = dim;
   if( NumberOfDimensions == 2 )
     {
@@ -124,7 +124,7 @@ unsigned int Bitmap::GetPlanarConfiguration() const
     assert(0);
     // LEADTOOLS_FLOWERS-8-PAL-RLE.dcm
     // User specify PlanarConfiguration whereas SamplesPerPixel != 3
-    gdcmWarningMacro( 
+    gdcmWarningMacro(
       "Can't set PlanarConfiguration if SamplesPerPixel is not 3" );
     // Let's assume it's this way...
     return 0;
@@ -136,7 +136,7 @@ void Bitmap::SetPlanarConfiguration(unsigned int pc)
 {
   // precondition
   assert( pc == 0 || pc == 1 );
-  // LEADTOOLS_FLOWERS-8-MONO2-Uncompressed.dcm   
+  // LEADTOOLS_FLOWERS-8-MONO2-Uncompressed.dcm
   if( pc ) assert( PF.GetSamplesPerPixel() == 3 ); // Please set PixelFormat first
   PlanarConfiguration = pc;
   // \postcondition
@@ -297,30 +297,36 @@ bool Bitmap::TryRAWCodec(char *buffer, bool &lossyflag) const
     codec.SetNeedByteSwap( GetNeedByteSwap() );
     codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
     DataElement out;
-    bool r = codec.Decode(PixelData, out);
+    //bool r = codec.Decode(PixelData, out);
+    bool r = codec.DecodeBytes(bv->GetPointer(), bv->GetLength(),
+      buffer, len);
     if( !r ) return false;
-    const ByteValue *outbv = out.GetByteValue();
-    assert( outbv );
+    //const ByteValue *outbv = out.GetByteValue();
+    //assert( outbv );
     if( len != bv->GetLength() )
       {
       // SIEMENS_GBS_III-16-ACR_NEMA_1.acr
       // This is also handling the famous DermaColorLossLess.dcm issue
-      // where RGB image is odd length (GetBufferLength()) but 
+      // where RGB image is odd length (GetBufferLength()) but
       // ByteValue::GetLength is rounded up to the next even byte length
-      gdcmDebugMacro( "Pixel Length " << bv->GetLength() <<
-        " is different from computed value " << len );
-      ((ByteValue*)outbv)->SetLength( len );
+    //  gdcmDebugMacro( "Pixel Length " << bv->GetLength() <<
+    //    " is different from computed value " << len );
+    //  ((ByteValue*)outbv)->SetLength( len );
       }
+#if 0
     if ( GetPixelFormat() != codec.GetPixelFormat() )
       {
       gdcm::Bitmap *i = (gdcm::Bitmap*)this;
       i->SetPixelFormat( codec.GetPixelFormat() );
       }
+#endif
 
-    unsigned long check = outbv->GetLength();  // FIXME
+    unsigned long check; // = outbv->GetLength();  // FIXME
+    check = len;
     // DermaColorLossLess.dcm
     assert( check == len || check == len + 1 );
-    if(buffer) memcpy(buffer, outbv->GetPointer(), outbv->GetLength() );  // FIXME
+    (void)check;// removing warning
+    //if(buffer) memcpy(buffer, outbv->GetPointer(), outbv->GetLength() );  // FIXME
     return r;
     }
   return false;
@@ -349,6 +355,15 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
       if(!b) return false;
       assert( b );
       lossyflag = codec.IsLossy();
+      // we need to know the actual pixeltype after ::Read
+#if 0
+      if( codec.GetPixelFormat() != GetPixelFormat() )
+        {
+        gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+        i->SetPixelFormat( codec.GetPixelFormat() );
+        }
+#endif
+
       return true;
       }
     return false;
@@ -363,7 +378,7 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
     codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
     DataElement out;
     bool r = codec.Decode(PixelData, out);
-    // PHILIPS_Gyroscan-12-MONO2-Jpeg_Lossless.dcm    
+    // PHILIPS_Gyroscan-12-MONO2-Jpeg_Lossless.dcm
     if( !r )
       {
       return false;
@@ -380,16 +395,24 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
     //if ( GetPhotometricInterpretation() != codec.GetPhotometricInterpretation() )
     //  {
     //  // HACK
-    //  // YBRisGray.dcm 
+    //  // YBRisGray.dcm
     //  gdcm::Bitmap *i = (gdcm::Bitmap*)this;
     //  i->SetPhotometricInterpretation( codec.GetPhotometricInterpretation() );
     //  }
+#if 1
     if ( GetPixelFormat() != codec.GetPixelFormat() )
       {
+      // gdcmData/DCMTK_JPEGExt_12Bits.dcm
+      assert( GetPixelFormat().GetPixelRepresentation() ==
+        codec.GetPixelFormat().GetPixelRepresentation() );
+      assert( GetPixelFormat().GetBitsStored() ==
+        codec.GetPixelFormat().GetBitsStored() );
+      assert( GetPixelFormat().GetBitsAllocated() == 12 );
       gdcm::Bitmap *i = (gdcm::Bitmap*)this;
       i->SetPixelFormat( codec.GetPixelFormat() );
       }
-    //if ( GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL_422 
+#endif
+    //if ( GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL_422
     //|| GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL )
     //  {
     //  gdcm::Bitmap *i = (gdcm::Bitmap*)this;
@@ -426,7 +449,7 @@ bool Bitmap::TryJPEGCodec2(std::ostream &os) const
     codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
     DataElement out;
     bool r = codec.Code(PixelData, out);
-    // PHILIPS_Gyroscan-12-MONO2-Jpeg_Lossless.dcm    
+    // PHILIPS_Gyroscan-12-MONO2-Jpeg_Lossless.dcm
     if( !r )
       {
       return false;
@@ -444,7 +467,7 @@ bool Bitmap::TryJPEGCodec2(std::ostream &os) const
     unsigned long check = outbv->GetLength();  // FIXME
     (void)check;
     // DermaColorLossLess.dcm has a len of 63531, but DICOM will give us: 63532 ...
-    assert( outbv->GetLength() < len );
+    assert( outbv->GetLength() < len ); (void)len;
     //memcpy(buffer, outbv->GetPointer(), outbv->GetLength() );
     os.write( outbv->GetPointer(), outbv->GetLength() );
 
@@ -528,12 +551,46 @@ bool Bitmap::TryKAKADUCodec(char *buffer, bool &lossyflag) const
 
 bool Bitmap::TryJPEGLSCodec(char *buffer, bool &lossyflag) const
 {
-  unsigned long len = GetBufferLength();
-  const TransferSyntax &ts = GetTransferSyntax();
-
   JPEGLSCodec codec;
+  const TransferSyntax &ts = GetTransferSyntax();
+  if(!buffer)
+    {
+    if( codec.CanDecode( ts ) ) // short path
+      {
+      TransferSyntax ts2;
+      const SequenceOfFragments *sf = PixelData.GetSequenceOfFragments();
+      if( !sf ) return false;
+      const Fragment &frag = sf->GetFragment(0);
+      const ByteValue &bv2 = dynamic_cast<const ByteValue&>(frag.GetValue());
+
+      std::stringstream ss;
+      ss.write( bv2.GetPointer(), bv2.GetLength() );
+      bool b = codec.GetHeaderInfo( ss, ts2 );
+      //bool b = codec.GetHeaderInfo( bv2.GetPointer(), bv2.GetLength() , ts2 );
+      if( !b ) return false;
+      lossyflag = codec.IsLossy();
+      // we need to know the actual pixeltype after ::Read
+#if 0
+// This is actually very dangerous to change the pixel format right here. What if
+// user stored a 16/10/9 signed image using JPEG-LS, JPEG-LS would be required to use
+// the full spectrum of the unsigned short 16 bits range to store that image and would
+// therefore -rightfully- declared as 16 bits...
+      if( codec.GetPixelFormat() != GetPixelFormat() )
+        {
+        gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+        i->SetPixelFormat( codec.GetPixelFormat() );
+        }
+#endif
+
+      return true;
+      }
+    return false;
+    }
+
+
   if( codec.CanDecode( ts ) )
     {
+    unsigned long len = GetBufferLength();
     codec.SetPixelFormat( GetPixelFormat() );
     codec.SetBufferLength( len );
     codec.SetNumberOfDimensions( GetNumberOfDimensions() );
@@ -586,7 +643,7 @@ bool Bitmap::ComputeLossyFlag()
     return true;
     }
   LossyFlag = false;
-  return false; 
+  return false;
 }
 
 bool Bitmap::TryJPEG2000Codec(char *buffer, bool &lossyflag) const
@@ -606,6 +663,37 @@ bool Bitmap::TryJPEG2000Codec(char *buffer, bool &lossyflag) const
       bool b = codec.GetHeaderInfo( bv2.GetPointer(), bv2.GetLength() , ts2 );
       if( !b ) return false;
       lossyflag = codec.IsLossy();
+      // we need to know the actual pixeltype after ::Read
+#if 0
+      if( codec.GetPixelFormat() != GetPixelFormat() )
+        {
+        // Because J2K support the full spectrum I do not see any issue
+        // with the following:
+        gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+        i->SetPixelFormat( codec.GetPixelFormat() );
+        }
+#else
+      // lets only check the only issue we have:
+      // OsirixFake16BitsStoredFakeSpacing.dcm
+      const PixelFormat & cpf = codec.GetPixelFormat();
+      const PixelFormat & pf = GetPixelFormat();
+      if( cpf.GetBitsAllocated() == pf.GetBitsAllocated() )
+        {
+        if( cpf.GetPixelRepresentation() == pf.GetPixelRepresentation() )
+          {
+          if( cpf.GetSamplesPerPixel() == pf.GetSamplesPerPixel() )
+            {
+            if( cpf.GetBitsStored() < pf.GetBitsStored() )
+              {
+              gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+              gdcmWarningMacro( "Encapsulated stream has fewer bits actually stored on disk. correcting." );
+              i->GetPixelFormat().SetBitsStored( cpf.GetBitsStored() );
+              }
+            }
+          }
+        }
+#endif
+
       return true;
       }
     return false;
@@ -613,7 +701,7 @@ bool Bitmap::TryJPEG2000Codec(char *buffer, bool &lossyflag) const
 
   if( codec.CanDecode( ts ) )
     {
-  unsigned long len = GetBufferLength();
+    unsigned long len = GetBufferLength();
     codec.SetPixelFormat( GetPixelFormat() );
     codec.SetNumberOfDimensions( GetNumberOfDimensions() );
     codec.SetPlanarConfiguration( GetPlanarConfiguration() );
@@ -638,11 +726,34 @@ bool Bitmap::TryJPEG2000Codec(char *buffer, bool &lossyflag) const
       assert( !ts.IsLossy() );
       gdcmErrorMacro( "EVIL file, it is declared as lossless but is in fact lossy." );
       }
+#if 0
     if( codec.GetPixelFormat() != GetPixelFormat() )
       {
       gdcm::Bitmap *i = (gdcm::Bitmap*)this;
       i->SetPixelFormat( codec.GetPixelFormat() );
       }
+#else
+      // lets only check the only issue we have:
+      // OsirixFake16BitsStoredFakeSpacing.dcm
+      const PixelFormat & cpf = codec.GetPixelFormat();
+      const PixelFormat & pf = GetPixelFormat();
+      if( cpf.GetBitsAllocated() == pf.GetBitsAllocated() )
+        {
+        if( cpf.GetPixelRepresentation() == pf.GetPixelRepresentation() )
+          {
+          if( cpf.GetSamplesPerPixel() == pf.GetSamplesPerPixel() )
+            {
+            if( cpf.GetBitsStored() < pf.GetBitsStored() )
+              {
+              gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+              gdcmWarningMacro( "Encapsulated stream has fewer bits actually stored on disk. correcting." );
+              i->GetPixelFormat().SetBitsStored( cpf.GetBitsStored() );
+              }
+            }
+          }
+        }
+
+#endif
     return r;
     }
   return false;
@@ -767,5 +878,27 @@ bool Bitmap::IsTransferSyntaxCompatible( TransferSyntax const & ts ) const
   return false;
 }
 
+void Bitmap::Print(std::ostream &os) const
+{
+  Object::Print(os);
+  //assert( NumberOfDimensions );
+  os << "NumberOfDimensions: " << NumberOfDimensions << "\n";
+  if( NumberOfDimensions )
+    {
+    assert( Dimensions.size() );
+    os << "Dimensions: (";
+    std::vector<unsigned int>::const_iterator it = Dimensions.begin();
+    os << *it;
+    for(++it; it != Dimensions.end(); ++it)
+      {
+      os << "," << *it;
+      }
+    os << ")\n";
+    PF.Print(os);
+    }
+  os << "PhotometricInterpretation: " << PI << "\n";
+  os << "PlanarConfiguration: " << PlanarConfiguration << "\n";
+  os << "TransferSyntax: " << TS << "\n";
+}
 
 }
