@@ -30,7 +30,7 @@
 
 namespace gdcm
 {
-  
+
 /**
  * \brief Bitmap class
  * A bitmap based image. Used as parent for both IconImage and the main Pixel Data Image
@@ -41,7 +41,7 @@ class GDCM_EXPORT Bitmap : public Object
 public:
   Bitmap();
   ~Bitmap();
-  void Print(std::ostream &) const {}
+  void Print(std::ostream &) const;
 
   virtual bool AreOverlaysInPixelData() const { return false; }
 
