@@ -25,9 +25,13 @@
 #include "gdcmAttribute.h"
 #include "gdcmImage.h"
 #include "gdcmDirectionCosines.h"
+#include "gdcmSegmentedPaletteColorLookupTable.h"
+#include "gdcmByteValue.h"
+
+#include <math.h> // fabs
 
   /* TODO:
-   * 
+   *
    * (0028,9145) SQ (Sequence with undefined length #=1)     # u/l, 1 PixelValueTransformationSequence
    * (fffe,e000) na (Item with undefined length #=3)         # u/l, 1 Item
    * (0028,1052) DS [0.00000]                                #   8, 1 RescaleIntercept
@@ -35,7 +39,7 @@
    * (0028,1054) LO [US]                                     #   2, 1 RescaleType
    * (fffe,e00d) na (ItemDelimitationItem)                   #   0, 0 ItemDelimitationItem
    * (fffe,e0dd) na (SequenceDelimitationItem)               #   0, 0 SequenceDelimitationItem
-   * 
+   *
    * Same goes for window level...
    */
 
@@ -62,7 +66,7 @@ bool GetOriginValueFromSequence(const DataSet& ds, const Tag& tfgs, std::vector<
   assert( sqi2 );
   const Item &item2 = sqi2->GetItem(1);
   const DataSet & subds2 = item2.GetNestedDataSet();
-  // 
+  //
   const Tag tps(0x0020,0x0032);
   if( !subds2.FindDataElement(tps) ) return false;
   const DataElement &de = subds2.GetDataElement( tps );
@@ -95,7 +99,7 @@ bool GetDirectionCosinesValueFromSequence(const DataSet& ds, const Tag& tfgs, st
   // Take it from the first item
   const Item &item2 = sqi2->GetItem(1);
   const DataSet & subds2 = item2.GetNestedDataSet();
-  // 
+  //
   const Tag tps(0x0020,0x0037);
   if( !subds2.FindDataElement(tps) ) return false;
   const DataElement &de = subds2.GetDataElement( tps );
@@ -164,7 +168,7 @@ bool ComputeZSpacingFromIPP(const DataSet &ds, double &zspacing)
   std::vector<double> cosines;
   // For some reason TOSHIBA-EnhancedCT.dcm is storing the direction cosines in the per-frame section
   // and not the shared one... oh well
-  bool b1 = GetDirectionCosinesValueFromSequence(ds, t1, cosines) 
+  bool b1 = GetDirectionCosinesValueFromSequence(ds, t1, cosines)
     || GetDirectionCosinesValueFromSequence(ds,t2,cosines);
   if(!b1)
     {
@@ -199,9 +203,9 @@ bool ComputeZSpacingFromIPP(const DataSet &ds, double &zspacing)
 
   // For each item
   std::vector<double> distances;
-  unsigned int nitems = sqi->GetNumberOfItems();
+  gdcm::SequenceOfItems::SizeType nitems = sqi->GetNumberOfItems();
   std::vector<double> dircos_subds2; dircos_subds2.resize(6);
-  for(unsigned int i = 1; i <= nitems; ++i)
+  for(gdcm::SequenceOfItems::SizeType i = 1; i <= nitems; ++i)
     {
     const Item &item = sqi->GetItem(i);
     const DataSet & subds = item.GetNestedDataSet();
@@ -238,7 +242,7 @@ bool ComputeZSpacingFromIPP(const DataSet &ds, double &zspacing)
     prev = distances[i];
     }
   meanspacing /= (nitems - 1);
-  
+
   //zspacing = distances[1] - distances[0];
   zspacing = meanspacing;
 
@@ -363,7 +367,7 @@ bool GetUltraSoundSpacingValueFromSequence(const DataSet& ds, std::vector<double
   assert( at2.GetNumberOfValues() == 1 );
   sp.push_back( at1.GetValue() );
   sp.push_back( at2.GetValue() );
- 
+
   return true;
 }
 
@@ -397,17 +401,20 @@ std::vector<double> ImageHelper::GetOriginValue(File const & f)
   const DataSet& ds = f.GetDataSet();
 
   if( ms == MediaStorage::EnhancedCTImageStorage
-   || ms == MediaStorage::EnhancedMRImageStorage )
+   || ms == MediaStorage::EnhancedMRImageStorage
+   || ms == MediaStorage::SegmentationStorage )
     {
     const Tag t1(0x5200,0x9229);
     const Tag t2(0x5200,0x9230);
-    if( GetOriginValueFromSequence(ds,t1, ori) 
+    if( GetOriginValueFromSequence(ds,t1, ori)
      || GetOriginValueFromSequence(ds, t2, ori) )
       {
       assert( ori.size() == 3 );
       return ori;
       }
-    assert(0);
+    ori.resize( 3 );
+    gdcmWarningMacro( "Could not find Origin" );
+    return ori;
     }
   ori.resize( 3 );
 
@@ -484,11 +491,12 @@ std::vector<double> ImageHelper::GetDirectionCosinesValue(File const & f)
   const DataSet& ds = f.GetDataSet();
 
   if( ms == MediaStorage::EnhancedCTImageStorage
-   || ms == MediaStorage::EnhancedMRImageStorage )
+   || ms == MediaStorage::EnhancedMRImageStorage
+   || ms == MediaStorage::SegmentationStorage )
     {
     const Tag t1(0x5200,0x9229);
     const Tag t2(0x5200,0x9230);
-    if( GetDirectionCosinesValueFromSequence(ds,t1, dircos) 
+    if( GetDirectionCosinesValueFromSequence(ds,t1, dircos)
      || GetDirectionCosinesValueFromSequence(ds, t2, dircos) )
       {
       assert( dircos.size() == 6 );
@@ -582,6 +590,115 @@ bool GetRescaleInterceptSlopeValueFromDataSet(const DataSet& ds, std::vector<dou
   return true;
 }
 
+
+/// This function returns pixel information about an image from its dataset
+/// That includes samples per pixel and bit depth (in that order)
+/// Returns a PixelFormat
+PixelFormat ImageHelper::GetPixelFormatValue(const File& f)
+{
+  // D 0028|0011 [US] [Columns] [512]
+  //[10/20/10 9:05:07 AM] Mathieu Malaterre:
+  PixelFormat pf;
+  const DataSet& ds = f.GetDataSet();
+  // D 0028|0100 [US] [Bits Allocated] [16]
+  {
+    //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0100) );
+    Attribute<0x0028,0x0100> at = { 0 };
+    at.SetFromDataSet( ds );
+    pf.SetBitsAllocated( at.GetValue() );
+  }
+  // D 0028|0101 [US] [Bits Stored] [12]
+  {
+    //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0101) );
+    Attribute<0x0028,0x0101> at = { 0 };
+    at.SetFromDataSet( ds );
+    pf.SetBitsStored( at.GetValue() );
+  }
+  // D 0028|0102 [US] [High Bit] [11]
+  {
+    //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0102) );
+    Attribute<0x0028,0x0102> at = { 0 };
+    at.SetFromDataSet( ds );
+    pf.SetHighBit( at.GetValue() );
+  }
+  // D 0028|0103 [US] [Pixel Representation] [0]
+  {
+    //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0103) );
+    Attribute<0x0028,0x0103> at = { 0 };
+    at.SetFromDataSet( ds );
+    pf.SetPixelRepresentation( at.GetValue() );
+  }
+  // (0028,0002) US 1                                        #   2, 1 SamplesPerPixel
+  {
+  //if( ds.FindDataElement( Tag(0x0028, 0x0002) ) )
+  {
+    //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0002) );
+    Attribute<0x0028,0x0002> at = { 1 };
+    at.SetFromDataSet( ds );
+    pf.SetSamplesPerPixel( at.GetValue() );
+  }
+  // else pf will default to 1...
+  }
+  return pf;
+
+}
+/// This function checks tags (0x0028, 0x0010) and (0x0028, 0x0011) for the
+/// rows and columns of the image in pixels (as opposed to actual distances).
+/// Also checks 0054, 0081 for the number of z slices for a 3D image
+/// If that tag is not present, default the z dimension to 1
+std::vector<unsigned int> ImageHelper::GetDimensionsValue(const File& f)
+{
+  DataSet const & ds = f.GetDataSet();
+
+  //const DataSet& ds = inF.GetDataSet();
+  std::vector<unsigned int> theReturn(3);
+  {
+    //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0011) );
+    Attribute<0x0028,0x0011> at = { 0 };
+    at.SetFromDataSet( ds );
+    theReturn[0] = at.GetValue();
+    //if( theReturn[0] == 0 )
+    //  {
+    //  // come' on ! WTF
+    //  gdcmWarningMacro( "Cannot find image extent tag 0x0028, 0x0011.  Defaulting to the almost certainly wrong value of 1." );
+    //  theReturn[0] = 1;
+    //  }
+  }
+
+  // D 0028|0010 [US] [Rows] [512]
+  {
+    //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0010) );
+    Attribute<0x0028,0x0010> at = { 0 };
+    at.SetFromDataSet( ds );
+    theReturn[1] = at.GetValue();
+    //if( theReturn[1] == 0 )
+    //  {
+    //  // come' on ! WTF
+    //  gdcmWarningMacro( "Cannot find image extent tag 0x0028, 0x0010.  Defaulting to the almost certainly wrong value of 1." );
+    //  theReturn[1] = 1;
+    //  }
+  }
+  // D 0054|0081 [US] [Planes] [512]
+  {
+    //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0010) );
+    Tag thePlanes(0x0054,0x0081);
+    if (ds.FindDataElement(thePlanes)){
+      Attribute<0x0054,0x0081> at = { 0 };
+      at.SetFromDataSet( ds );
+      theReturn[2] = at.GetValue();
+    } else {
+      theReturn[2] = 1;
+    }
+    //if( theReturn[1] == 0 )
+    //  {
+    //  // come' on ! WTF
+    //  gdcmWarningMacro( "Cannot find image extent tag 0x0028, 0x0010.  Defaulting to the almost certainly wrong value of 1." );
+    //  theReturn[1] = 1;
+    //  }
+  }
+  return theReturn;
+}
+
 std::vector<double> ImageHelper::GetRescaleInterceptSlopeValue(File const & f)
 {
   std::vector<double> interceptslope;
@@ -590,11 +707,12 @@ std::vector<double> ImageHelper::GetRescaleInterceptSlopeValue(File const & f)
   const DataSet& ds = f.GetDataSet();
 
   if( ms == MediaStorage::EnhancedCTImageStorage
-   || ms == MediaStorage::EnhancedMRImageStorage )
+   || ms == MediaStorage::EnhancedMRImageStorage
+   || ms == MediaStorage::SegmentationStorage )
     {
     const Tag t1(0x5200,0x9229);
     const Tag t2(0x5200,0x9230);
-    if( GetInterceptSlopeValueFromSequence(ds,t1, interceptslope) 
+    if( GetInterceptSlopeValueFromSequence(ds,t1, interceptslope)
      || GetInterceptSlopeValueFromSequence(ds,t2, interceptslope) )
       {
       assert( interceptslope.size() == 2 );
@@ -606,6 +724,7 @@ std::vector<double> ImageHelper::GetRescaleInterceptSlopeValue(File const & f)
       interceptslope[0] = 0;
       interceptslope[1] = 1;
       bool b = GetRescaleInterceptSlopeValueFromDataSet(ds, interceptslope);
+      gdcmAssertMacro( b ); (void)b;
       return interceptslope;
       }
     }
@@ -621,10 +740,26 @@ std::vector<double> ImageHelper::GetRescaleInterceptSlopeValue(File const & f)
  || ms == MediaStorage::SecondaryCaptureImageStorage
  || ms == MediaStorage::MultiframeGrayscaleWordSecondaryCaptureImageStorage
  || ms == MediaStorage::MultiframeGrayscaleByteSecondaryCaptureImageStorage
- || ForceRescaleInterceptSlope 
+ || ForceRescaleInterceptSlope
   )
     {
     bool b = GetRescaleInterceptSlopeValueFromDataSet(ds, interceptslope);
+    gdcmAssertMacro( b ); (void)b;
+    }
+  else if (
+    ms == MediaStorage::RTDoseStorage
+  )
+    {
+    Attribute<0x3004,0x000e> gridscaling = { 0 };
+    gridscaling.SetFromDataSet( ds );
+    interceptslope[0] = 0;
+    interceptslope[1] = gridscaling.GetValue();
+    if( interceptslope[1] == 0 )
+      {
+      // come' on ! WTF
+      gdcmWarningMacro( "Cannot have slope == 0. Defaulting to 1.0 instead" );
+      interceptslope[1] = 1;
+      }
     }
 
   // \post condition slope can never be 0:
@@ -795,12 +930,13 @@ std::vector<double> ImageHelper::GetSpacingValue(File const & f)
   const DataSet& ds = f.GetDataSet();
 
   if( ms == MediaStorage::EnhancedCTImageStorage
-    ||  ms == MediaStorage::EnhancedMRImageStorage )
+    || ms == MediaStorage::EnhancedMRImageStorage
+    || ms == MediaStorage::SegmentationStorage )
     {
     // <entry group="5200" element="9230" vr="SQ" vm="1" name="Per-frame Functional Groups Sequence"/>
     const Tag t1(0x5200,0x9229);
     const Tag t2(0x5200,0x9230);
-    if( GetSpacingValueFromSequence(ds,t1, sp) 
+    if( GetSpacingValueFromSequence(ds,t1, sp)
       || GetSpacingValueFromSequence(ds, t2, sp) )
       {
       assert( sp.size() == 3 );
@@ -808,7 +944,9 @@ std::vector<double> ImageHelper::GetSpacingValue(File const & f)
       }
     // Else.
     // How do I send an error ?
-    sp.push_back( 0.0 ); // FIXME !!
+    sp.resize( 3 ); // FIXME !!
+    sp[2] = 1.;
+    gdcmWarningMacro( "Could not find Spacing" );
     return sp;
     }
   else if( ms == MediaStorage::UltrasoundMultiFrameImageStorage )
@@ -858,8 +996,8 @@ std::vector<double> ImageHelper::GetSpacingValue(File const & f)
         // I would need to throw an expection that VM is not compatible
         el.SetLength( entry.GetVM().GetLength() * entry.GetVR().GetSizeof() );
         el.Read( ss );
-        assert( el.GetLength() == 2 ); 
-        for(unsigned long i = 0; i < el.GetLength(); ++i) 
+        assert( el.GetLength() == 2 );
+        for(unsigned long i = 0; i < el.GetLength(); ++i)
           sp.push_back( el.GetValue(i) );
         std::swap( sp[0], sp[1]);
         assert( sp.size() == (unsigned int)entry.GetVM() );
@@ -875,7 +1013,7 @@ std::vector<double> ImageHelper::GetSpacingValue(File const & f)
         ss.str( s );
         el.SetLength( entry.GetVM().GetLength() * entry.GetVR().GetSizeof() );
         el.Read( ss );
-        for(unsigned long i = 0; i < el.GetLength(); ++i) 
+        for(unsigned long i = 0; i < el.GetLength(); ++i)
           sp.push_back( el.GetValue(i) );
         assert( sp.size() == (unsigned int)entry.GetVM() );
         }
@@ -921,7 +1059,7 @@ std::vector<double> ImageHelper::GetSpacingValue(File const & f)
             ss.str( s );
             el.SetLength( entry.GetVM().GetLength() * entry.GetVR().GetSizeof() );
             el.Read( ss );
-            for(unsigned long i = 0; i < el.GetLength(); ++i) 
+            for(unsigned long i = 0; i < el.GetLength(); ++i)
               sp.push_back( el.GetValue(i) );
             //assert( sp.size() == entry.GetVM() );
             }
@@ -1001,7 +1139,8 @@ void ImageHelper::SetSpacingValue(DataSet & ds, const std::vector<double> & spac
   assert( spacing.size() == 3 );
 
   if( ms == MediaStorage::EnhancedCTImageStorage
-   || ms == MediaStorage::EnhancedMRImageStorage )
+   || ms == MediaStorage::EnhancedMRImageStorage
+   || ms == MediaStorage::SegmentationStorage )
     {
 /*
     (0028,9110) SQ (Sequence with undefined length #=1)     # u/l, 1 PixelMeasuresSequence
@@ -1105,7 +1244,8 @@ void ImageHelper::SetSpacingValue(DataSet & ds, const std::vector<double> & spac
           el.Write( os );
           de.SetVR( VR::DS );
           if( os.str().size() % 2 ) os << " ";
-          de.SetByteValue( os.str().c_str(), os.str().size() );
+          VL::Type osStrSize = (VL::Type)os.str().size();
+          de.SetByteValue( os.str().c_str(),osStrSize );
           ds.Replace( de );
           }
         break;
@@ -1123,7 +1263,8 @@ void ImageHelper::SetSpacingValue(DataSet & ds, const std::vector<double> & spac
           el.Write( os );
           de.SetVR( VR::IS );
           if( os.str().size() % 2 ) os << " ";
-          de.SetByteValue( os.str().c_str(), os.str().size() );
+          VL::Type osStrSize = (VL::Type)os.str().size();
+          de.SetByteValue( os.str().c_str(), osStrSize );
           ds.Replace( de );
           }
         break;
@@ -1165,7 +1306,8 @@ void ImageHelper::SetSpacingValue(DataSet & ds, const std::vector<double> & spac
             std::stringstream os;
             el.Write( os );
             de.SetVR( VR::DS );
-            de.SetByteValue( os.str().c_str(), os.str().size() );
+            VL::Type osStrSize = (VL::Type)os.str().size();
+            de.SetByteValue( os.str().c_str(), osStrSize );
             ds.Replace( de );
 
         }
@@ -1187,7 +1329,8 @@ void ImageHelper::SetSpacingValue(DataSet & ds, const std::vector<double> & spac
             el.Write( os );
             de.SetVR( VR::DS );
             if( os.str().size() % 2 ) os << " ";
-            de.SetByteValue( os.str().c_str(), os.str().size() );
+            VL::Type osStrSize = (VL::Type)os.str().size();
+            de.SetByteValue( os.str().c_str(), osStrSize );
             ds.Replace( de );
             }
           break;
@@ -1276,6 +1419,7 @@ void ImageHelper::SetOriginValue(DataSet & ds, const Image & image)
    && ms != MediaStorage::MRImageStorage
    && ms != MediaStorage::RTDoseStorage
    //&& ms != MediaStorage::ComputedRadiographyImageStorage
+   && ms != MediaStorage::SegmentationStorage
    && ms != MediaStorage::EnhancedMRImageStorage
    && ms != MediaStorage::EnhancedCTImageStorage )
     {
@@ -1284,7 +1428,8 @@ void ImageHelper::SetOriginValue(DataSet & ds, const Image & image)
     }
 
   if( ms == MediaStorage::EnhancedCTImageStorage
-   || ms == MediaStorage::EnhancedMRImageStorage )
+   || ms == MediaStorage::EnhancedMRImageStorage
+   || ms == MediaStorage::SegmentationStorage )
     {
 /*
     (0020,9113) SQ (Sequence with undefined length #=1)     # u/l, 1 PlanePositionSequence
@@ -1351,6 +1496,7 @@ void ImageHelper::SetDirectionCosinesValue(DataSet & ds, const std::vector<doubl
    && ms != MediaStorage::MRImageStorage
    && ms != MediaStorage::RTDoseStorage
    //&& ms != MediaStorage::ComputedRadiographyImageStorage
+   && ms != MediaStorage::SegmentationStorage
    && ms != MediaStorage::EnhancedMRImageStorage
    && ms != MediaStorage::EnhancedCTImageStorage )
     {
@@ -1378,7 +1524,8 @@ void ImageHelper::SetDirectionCosinesValue(DataSet & ds, const std::vector<doubl
     }
 
   if( ms == MediaStorage::EnhancedCTImageStorage
-   || ms == MediaStorage::EnhancedMRImageStorage )
+   || ms == MediaStorage::EnhancedMRImageStorage
+   || ms == MediaStorage::SegmentationStorage )
     {
 /*
     (0020,9116) SQ (Sequence with undefined length #=1)     # u/l, 1 PlaneOrientationSequence
@@ -1454,11 +1601,13 @@ void ImageHelper::SetRescaleInterceptSlopeValue(File & f, const Image & img)
    && ms != MediaStorage::ComputedRadiographyImageStorage
    && ms != MediaStorage::MRImageStorage // FIXME !
    && ms != MediaStorage::PETImageStorage
+   && ms != MediaStorage::RTDoseStorage
    && ms != MediaStorage::SecondaryCaptureImageStorage
    && ms != MediaStorage::MultiframeGrayscaleWordSecondaryCaptureImageStorage
    && ms != MediaStorage::MultiframeGrayscaleByteSecondaryCaptureImageStorage
    && ms != MediaStorage::EnhancedMRImageStorage
-   && ms != MediaStorage::EnhancedCTImageStorage )
+   && ms != MediaStorage::EnhancedCTImageStorage
+   && ms != MediaStorage::SegmentationStorage )
     {
     if( img.GetIntercept() != 0. || img.GetSlope() != 1. )
       {
@@ -1467,8 +1616,10 @@ void ImageHelper::SetRescaleInterceptSlopeValue(File & f, const Image & img)
     return;
     }
 
+  if( ms == MediaStorage::SegmentationStorage ) return; // seg storage cannot have rescale slope
   if( ms == MediaStorage::EnhancedCTImageStorage
-   || ms == MediaStorage::EnhancedMRImageStorage )
+   || ms == MediaStorage::EnhancedMRImageStorage
+  )
     {
 /*
     (0020,9116) SQ (Sequence with undefined length #=1)     # u/l, 1 PlaneOrientationSequence
@@ -1534,6 +1685,15 @@ void ImageHelper::SetRescaleInterceptSlopeValue(File & f, const Image & img)
     return;
     }
 
+  if( ms == MediaStorage::RTDoseStorage )
+    {
+    Attribute<0x3004,0x00e> at2;
+    at2.SetValue( img.GetSlope() );
+    ds.Replace( at2.GetAsDataElement() );
+
+    return;
+    }
+
   // Question: should I always insert them ?
   // Answer: not always, let's discard MR if (1,0):
   if( ms == MediaStorage::MRImageStorage && img.GetIntercept() == 0. && img.GetSlope() == 1. )
@@ -1577,7 +1737,7 @@ bool ImageHelper::ComputeSpacingFromImagePositionPatient(const std::vector<doubl
     spacing[1] += y;
     spacing[2] += z;
     }
-  int n = imageposition.size() / 3;
+  size_t n = imageposition.size() / 3;
   spacing[0] /= n;
   spacing[1] /= n;
   spacing[2] /= n;
@@ -1586,4 +1746,253 @@ bool ImageHelper::ComputeSpacingFromImagePositionPatient(const std::vector<doubl
 }
 
 
+//functions to get more information from a file
+//useful for the stream image reader, which fills in necessary image information
+//distinctly from the reader-style data input
+//code is borrowed from gdcmPixmapReader::ReadImage(MediaStorage const &ms)
+PhotometricInterpretation ImageHelper::GetPhotometricInterpretationValue(File const& f){
+  // 5. Photometric Interpretation
+  // D 0028|0004 [CS] [Photometric Interpretation] [MONOCHROME2 ]
+  PixelFormat pf = GetPixelFormatValue(f);
+  const Tag tphotometricinterpretation(0x0028, 0x0004);
+  const ByteValue *photometricinterpretation =
+    ImageHelper::GetPointerFromElement(tphotometricinterpretation, f);
+  PhotometricInterpretation pi = PhotometricInterpretation::UNKNOW;
+  if( photometricinterpretation )
+    {
+    std::string photometricinterpretation_str(
+      photometricinterpretation->GetPointer(),
+      photometricinterpretation->GetLength() );
+    pi = PhotometricInterpretation::GetPIType( photometricinterpretation_str.c_str() );
+    }
+  else
+    {
+    if( pf.GetSamplesPerPixel() == 1 )
+      {
+      gdcmWarningMacro( "No PhotometricInterpretation found, default to MONOCHROME2" );
+      pi = PhotometricInterpretation::MONOCHROME2;
+      }
+    else if( pf.GetSamplesPerPixel() == 3 )
+      {
+      gdcmWarningMacro( "No PhotometricInterpretation found, default to RGB" );
+      pi = PhotometricInterpretation::RGB;
+      }
+    else if( pf.GetSamplesPerPixel() == 4 )
+      {
+      gdcmWarningMacro( "No PhotometricInterpretation found, default to RGB" );
+      pi = PhotometricInterpretation::ARGB;
+      }
+    }
+
+  bool isacrnema = false;
+  DataSet ds = f.GetDataSet();
+  const Tag trecognitioncode(0x0008,0x0010);
+  if( ds.FindDataElement( trecognitioncode ) && !ds.GetDataElement( trecognitioncode ).IsEmpty() )
+    {
+    // PHILIPS_Gyroscan-12-MONO2-Jpeg_Lossless.dcm
+    // PHILIPS_Gyroscan-12-Jpeg_Extended_Process_2_4.dcm
+    gdcmDebugMacro( "Mixture of ACR NEMA and DICOM file" );
+    isacrnema = true;
+  }
+  if( !pf.GetSamplesPerPixel() || (pi.GetSamplesPerPixel() != pf.GetSamplesPerPixel()) )
+    {
+    if( pi != PhotometricInterpretation::UNKNOW )
+      {
+      pf.SetSamplesPerPixel( pi.GetSamplesPerPixel() );
+      }
+    else if ( isacrnema )
+      {
+      assert ( pf.GetSamplesPerPixel() == 0 );
+      assert ( pi == PhotometricInterpretation::UNKNOW );
+      pf.SetSamplesPerPixel( 1 );
+      pi = PhotometricInterpretation::MONOCHROME2;
+      }
+    else
+      {
+      gdcmWarningMacro( "Cannot recognize image type. Does not looks like ACR-NEMA and is missing both Sample Per Pixel AND PhotometricInterpretation. Please report" );
+      }
+    }
+  return pi;
+}
+//returns the configuration of colors in a plane, either RGB RGB RGB or RRR GGG BBB
+//code is borrowed from gdcmPixmapReader::ReadImage(MediaStorage const &ms)
+unsigned int ImageHelper::GetPlanarConfigurationValue(const File& f){
+  // 4. Planar Configuration
+  // D 0028|0006 [US] [Planar Configuration] [1]
+  const Tag planarconfiguration = Tag(0x0028, 0x0006);
+  PixelFormat pf = GetPixelFormatValue(f);
+  unsigned int pc = 0;
+  // FIXME: Whatif planaconfiguration is send in a grayscale image... it would be empty...
+  // well hopefully :(
+  DataSet const & ds = f.GetDataSet();
+  if( ds.FindDataElement( planarconfiguration ) && !ds.GetDataElement( planarconfiguration ).IsEmpty() )
+    {
+    const DataElement& de = ds.GetDataElement( planarconfiguration );
+    Attribute<0x0028,0x0006> at = { 0 };
+    at.SetFromDataElement( de );
+
+    //unsigned int pc = ReadUSFromTag( planarconfiguration, ss, conversion );
+    pc = at.GetValue();
+    if( pc && pf.GetSamplesPerPixel() != 3 )
+      {
+      gdcmDebugMacro( "Cannot have PlanarConfiguration=1, when Sample Per Pixel != 3" );
+      pc = 0;
+      }
+    }
+  return pc;
+}
+
+  //returns the lookup table of an image file
+SmartPointer<LookupTable> ImageHelper::GetLUT(File const& f){
+
+  DataSet const & ds = f.GetDataSet();
+  PixelFormat pf = GetPixelFormatValue(f);
+  PhotometricInterpretation pi = GetPhotometricInterpretationValue(f);
+  // Do the Palette Color:
+  // 1. Modality LUT Sequence
+  bool modlut = ds.FindDataElement(Tag(0x0028,0x3000) );
+  if( modlut )
+    {
+    gdcmWarningMacro( "Modality LUT (0028,3000) are not handled. Image will not be displayed properly" );
+    }
+  // 2. LUTData (0028,3006)
+  // technically I do not need to warn about LUTData since either modality lut XOR VOI LUT need to
+  // be sent to require a LUT Data...
+  bool lutdata = ds.FindDataElement(Tag(0x0028,0x3006) );
+  if( lutdata )
+    {
+    gdcmWarningMacro( "LUT Data (0028,3006) are not handled. Image will not be displayed properly" );
+    }
+  // 3. VOILUTSequence (0028,3010)
+  bool voilut = ds.FindDataElement(Tag(0x0028,0x3010) );
+  if( voilut )
+    {
+    gdcmWarningMacro( "VOI LUT (0028,3010) are not handled. Image will not be displayed properly" );
+    }
+  // (0028,0120) US 32767                                    #   2, 1 PixelPaddingValue
+  bool pixelpaddingvalue = ds.FindDataElement(Tag(0x0028,0x0120));
+
+  // PS 3.3 - 2008 / C.7.5.1.1.2 Pixel Padding Value and Pixel Padding Range Limit
+  if(pixelpaddingvalue)
+    {
+    // Technically if Pixel Padding Value is 0 on MONOCHROME2 image, then appearance should be fine...
+    bool vizissue = true;
+    if( pf.GetPixelRepresentation() == 0 )
+      {
+      Element<VR::US,VM::VM1> ppv;
+      if( !ds.GetDataElement(Tag(0x0028,0x0120) ).IsEmpty() )
+        {
+        ppv.SetFromDataElement( ds.GetDataElement(Tag(0x0028,0x0120)) ); //.GetValue() );
+        if( pi == PhotometricInterpretation::MONOCHROME2 && ppv.GetValue() == 0 )
+          {
+          vizissue = false;
+          }
+        }
+      }
+    else if( pf.GetPixelRepresentation() == 1 )
+      {
+      gdcmDebugMacro( "TODO" );
+      }
+    // test if there is any viz issue:
+    if( vizissue )
+      {
+      gdcmDebugMacro( "Pixel Padding Value (0028,0120) is not handled. Image will not be displayed properly" );
+      }
+    }
+  SmartPointer<LookupTable> lut = new LookupTable;
+  const Tag testseglut(0x0028, (0x1221 + 0));
+  if( ds.FindDataElement( testseglut ) )
+    {
+    lut = new SegmentedPaletteColorLookupTable;
+    }
+  //SmartPointer<SegmentedPaletteColorLookupTable> lut = new SegmentedPaletteColorLookupTable;
+  lut->Allocate( pf.GetBitsAllocated() );
+
+  // for each red, green, blue:
+  for(int i=0; i<3; ++i)
+    {
+    // (0028,1101) US 0\0\16
+    // (0028,1102) US 0\0\16
+    // (0028,1103) US 0\0\16
+    const Tag tdescriptor(0x0028, (0x1101 + i));
+    //const Tag tdescriptor(0x0028, 0x3002);
+    Element<VR::US,VM::VM3> el_us3 = {{ 0, 0, 0}};
+    // Now pass the byte array to a DICOMizer:
+    el_us3.SetFromDataElement( ds[tdescriptor] ); //.GetValue() );
+    lut->InitializeLUT( LookupTable::LookupTableType(i),
+      el_us3[0], el_us3[1], el_us3[2] );
+
+    // (0028,1201) OW
+    // (0028,1202) OW
+    // (0028,1203) OW
+    const Tag tlut(0x0028, (0x1201 + i));
+    //const Tag tlut(0x0028, 0x3006);
+
+    // Segmented LUT
+    // (0028,1221) OW
+    // (0028,1222) OW
+    // (0028,1223) OW
+    const Tag seglut(0x0028, (0x1221 + i));
+    if( ds.FindDataElement( tlut ) )
+      {
+      const ByteValue *lut_raw = ds.GetDataElement( tlut ).GetByteValue();
+      if( lut_raw )
+        {
+        // LookupTableType::RED == 0
+        lut->SetLUT( LookupTable::LookupTableType(i),
+          (unsigned char*)lut_raw->GetPointer(), lut_raw->GetLength() );
+        //assert( pf.GetBitsAllocated() == el_us3.GetValue(2) );
+        }
+      else
+        {
+        lut->Clear();
+        }
+
+      unsigned long check =
+        (el_us3.GetValue(0) ? el_us3.GetValue(0) : 65536)
+        * el_us3.GetValue(2) / 8;
+      assert( !lut->Initialized() || check == lut_raw->GetLength() ); (void)check;
+      }
+    else if( ds.FindDataElement( seglut ) )
+      {
+      const ByteValue *lut_raw = ds.GetDataElement( seglut ).GetByteValue();
+      if( lut_raw )
+        {
+        lut->SetLUT( LookupTable::LookupTableType(i),
+          (unsigned char*)lut_raw->GetPointer(), lut_raw->GetLength() );
+        //assert( pf.GetBitsAllocated() == el_us3.GetValue(2) );
+        }
+      else
+        {
+        lut->Clear();
+        }
+
+      //unsigned long check =
+      //  (el_us3.GetValue(0) ? el_us3.GetValue(0) : 65536)
+       // * el_us3.GetValue(2) / 8;
+      //assert( check == lut_raw->GetLength() ); (void)check;
+      }
+    else
+      {
+      assert(0);
+      }
+    }
+  if( ! lut->Initialized() ) {
+    gdcmDebugMacro("LUT was uninitialized!");
+  }
+  return lut;
+}
+
+
+const ByteValue* ImageHelper::GetPointerFromElement(Tag const &tag, const File& inF) {
+
+  const DataSet &ds = inF.GetDataSet();
+  if( ds.FindDataElement( tag ) )
+    {
+    const DataElement &de = ds.GetDataElement( tag );
+    return de.GetByteValue();
+    }
+  return 0;
+}
+
 }
