@@ -35,13 +35,13 @@ class GDCM_EXPORT ImageReader : public PixmapReader
 {
 public:
   ImageReader();
-  ~ImageReader();
+  virtual ~ImageReader();//needs to be virtual to ensure lack of memory leaks
 
   /// Read the DICOM image. There are two reason for failure:
   /// 1. The input filename is not DICOM
   /// 2. The input DICOM file does not contains an Image.
-  
-  bool Read();
+
+  virtual bool Read();
 
   // Following methods are valid only after a call to 'Read'
 
@@ -58,4 +58,3 @@ protected:
 } // end namespace gdcm
 
 #endif //GDCMIMAGEREADER_H
-
