@@ -71,21 +71,36 @@ bool JPEGLSCodec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
 
   this->Dimensions[0] = metadata.width;
   this->Dimensions[1] = metadata.height;
-  switch( metadata.bitspersample )
+  if( metadata.bitspersample <= 8 )
     {
-  case 8:
     this->PF = PixelFormat( PixelFormat::UINT8 );
-    break;
-  case 12:
+    }
+  else if( metadata.bitspersample <= 16 )
+    {
+    assert( metadata.bitspersample > 8 );
     this->PF = PixelFormat( PixelFormat::UINT16 );
-    this->PF.SetBitsStored( 12 );
-    break;
-  case 16:
-    this->PF = PixelFormat( PixelFormat::UINT16 );
-    break;
-  default:
+    }
+  else
+    {
     assert(0);
     }
+  this->PF.SetBitsStored( metadata.bitspersample );
+  assert( this->PF.IsValid() );
+//  switch( metadata.bitspersample )
+//    {
+//  case 8:
+//    this->PF = PixelFormat( PixelFormat::UINT8 );
+//    break;
+//  case 12:
+//    this->PF = PixelFormat( PixelFormat::UINT16 );
+//    this->PF.SetBitsStored( 12 );
+//    break;
+//  case 16:
+//    this->PF = PixelFormat( PixelFormat::UINT16 );
+//    break;
+//  default:
+//    assert(0);
+//    }
   if( metadata.components == 1 )
     {
     PI = PhotometricInterpretation::MONOCHROME2;
@@ -98,6 +113,8 @@ bool JPEGLSCodec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
     }
   else assert(0);
 
+  // allowedlossyerror == 0 => Lossless
+  LossyFlag = metadata.allowedlossyerror;
 
   if( metadata.allowedlossyerror == 0 )
     {
@@ -118,7 +135,7 @@ bool JPEGLSCodec::CanDecode(TransferSyntax const &ts) const
 #ifndef GDCM_USE_JPEGLS
   return false;
 #else
-  return ts == TransferSyntax::JPEGLSLossless 
+  return ts == TransferSyntax::JPEGLSLossless
       || ts == TransferSyntax::JPEGLSNearLossless;
 #endif
 }
@@ -128,7 +145,7 @@ bool JPEGLSCodec::CanCode(TransferSyntax const &ts) const
 #ifndef GDCM_USE_JPEGLS
   return false;
 #else
-  return ts == TransferSyntax::JPEGLSLossless 
+  return ts == TransferSyntax::JPEGLSLossless
       || ts == TransferSyntax::JPEGLSNearLossless;
 #endif
 }
@@ -314,11 +331,7 @@ sample dit not suffer from that.
     // Using bitsstored for the encoder gives a slightly better compression ratio, and is indeed the
     // right way of doing it.
 
-/*
-FIXME: 12bits RGB is not working, so for now use the bitsallocated all the time
-Problem reading image from: /home/mathieu/Creatis/gdcmData/SIEMENS-MR-RGB-16Bits.dcm
-Found 8fd82891d8c7f146656aa88160c69b0b instead of faff9970b905458c0844400b5b869e25
-*/
+    // gdcmData/PHILIPS_Gyroscan-8-MONO2-Odd_Sequence.dcm
     if( true || pf.GetPixelRepresentation() )
       {
       // gdcmData/CT_16b_signed-UsedBits13.dcm
@@ -347,7 +360,7 @@ Found 8fd82891d8c7f146656aa88160c69b0b instead of faff9970b905458c0844400b5b869e
 
     size_t cbyteCompressed;
     JLS_ERROR error = JpegLsEncode(&rgbyteCompressed[0], rgbyteCompressed.size(), &cbyteCompressed, inputdata, inputlength, &params);
-    if( error != OK ) 
+    if( error != OK )
       {
       gdcmErrorMacro( "Error compressing: " << error );
       return false;
