@@ -19,7 +19,7 @@
 
 namespace gdcm
 {
-  
+
 class JPEGLSInternals;
 /**
  * \brief JPEG-LS
@@ -40,6 +40,9 @@ public:
   void SetBufferLength(unsigned long l) { BufferLength = l; }
 
   bool Decode(DataElement const &is, DataElement &os);
+  bool Decode(DataElement const &in, char* outBuffer, uint32_t inBufferLength,
+              uint32_t inXMin, uint32_t inXMax, uint32_t inYMin,
+              uint32_t inYMax, uint32_t inZMin, uint32_t inZMax) { return false; }
   bool Code(DataElement const &in, DataElement &out);
 
   bool GetHeaderInfo(std::istream &is, TransferSyntax &ts);
@@ -51,7 +54,7 @@ public:
  * test.acr can look pretty bad, even with a lossy error of 2. Explanation follows:
  * I agree that the test image looks ugly. In this particular case I can
  * explain though.
- * 
+ *
  * The image is 8 bit, but it does not use the full 8 bit dynamic range. The
  * black pixels have value 234 and the white 255. If you set allowed lossy
  * error to 2, you allow an error of about 10% of the actual dynamic range.
