@@ -22,7 +22,7 @@
 
 namespace gdcm
 {
-  
+
 /**
  * \brief Pixmap class
  * A bitmap based image. Used as parent for both IconImage and the main Pixel Data Image
@@ -35,34 +35,38 @@ class GDCM_EXPORT Pixmap : public Bitmap
 public:
   Pixmap();
   ~Pixmap();
-  void Print(std::ostream &) const {}
+  void Print(std::ostream &) const;
 
   /// returns if Overlays are stored in the unused bit of the pixel data:
   bool AreOverlaysInPixelData() const;
 
   /// Curve: group 50xx
-  Curve& GetCurve(unsigned int i = 0) { 
+  Curve& GetCurve(unsigned int i = 0) {
     assert( i < Curves.size() );
-    return Curves[i]; 
+    return Curves[i];
   }
-  const Curve& GetCurve(unsigned int i = 0) const { 
+  const Curve& GetCurve(unsigned int i = 0) const {
     assert( i < Curves.size() );
-    return Curves[i]; 
+    return Curves[i];
   }
-  unsigned int GetNumberOfCurves() const { return Curves.size(); }
-  void SetNumberOfCurves(unsigned int n) { Curves.resize(n); }
+  size_t GetNumberOfCurves() const { return Curves.size(); }
+  void SetNumberOfCurves(size_t n) { Curves.resize(n); }
 
   /// Overlay: group 60xx
-  Overlay& GetOverlay(unsigned int i = 0) { 
+  Overlay& GetOverlay(size_t i = 0) {
     assert( i < Overlays.size() );
-    return Overlays[i]; 
+    return Overlays[i];
   }
-  const Overlay& GetOverlay(unsigned int i = 0) const { 
+  const Overlay& GetOverlay(size_t i = 0) const {
     assert( i < Overlays.size() );
-    return Overlays[i]; 
+    return Overlays[i];
+  }
+  size_t GetNumberOfOverlays() const { return Overlays.size(); }
+  void SetNumberOfOverlays(size_t n) { Overlays.resize(n); }
+  void RemoveOverlay(size_t i) {
+    assert( i < Overlays.size() );
+    Overlays.erase( Overlays.begin() + i );
   }
-  unsigned int GetNumberOfOverlays() const { return Overlays.size(); }
-  void SetNumberOfOverlays(unsigned int n) { Overlays.resize(n); }
 
   /// Set/Get Icon Image
   const IconImage &GetIconImage() const { return Icon; }
