@@ -43,13 +43,13 @@ void PixmapWriter::SetPixmap(Pixmap const &img)
 void PixmapWriter::DoIconImage(DataSet & rootds, Pixmap const & image)
 {
   //const Tag ticonimage(0x0088,0x0200);
-  Attribute<0x0088,0x0200> iiat;
   const IconImage &icon = image.GetIconImage();
   if( !icon.IsEmpty() )
     {
     //DataElement iconimagesq = rootds.GetDataElement( ticonimage );
     //iconimagesq.SetTag( ticonimage );
     DataElement iconimagesq;
+    Attribute<0x0088,0x0200> iiat;
     iconimagesq.SetTag( iiat.GetTag() );
     iconimagesq.SetVR( VR::SQ );
     SmartPointer<SequenceOfItems> sq = new SequenceOfItems;
@@ -102,7 +102,8 @@ void PixmapWriter::DoIconImage(DataSet & rootds, Pixmap const & image)
 Attribute<0x0028,0x0004> piat;
     const char *pistr = PhotometricInterpretation::GetPIString(pi);
     DataElement de( Tag(0x0028, 0x0004 ) );
-    de.SetByteValue( pistr, strlen(pistr) );
+    VL::Type strlenPistr = (VL::Type)strlen(pistr);
+    de.SetByteValue( pistr, strlenPistr );
     de.SetVR( piat.GetVR() );
     ds.Replace( de );
 
@@ -228,7 +229,7 @@ Attribute<0x0028,0x0004> piat;
     iconimagesq.SetValue( *sq );
 
     rootds.Replace( iconimagesq );
-    
+
     }
 }
 
@@ -254,7 +255,7 @@ bool PixmapWriter::PrepareWrite()
   if( PixelData->GetNumberOfDimensions() == 3  )
     {
     Attribute<0x0028, 0x0008> numberofframes;
-    assert( PixelData->GetDimension(2) > 1 );
+    assert( PixelData->GetDimension(2) >= 1 );
     numberofframes.SetValue( PixelData->GetDimension(2) );
     ds.Replace( numberofframes.GetAsDataElement() );
     }
@@ -266,10 +267,15 @@ bool PixmapWriter::PrepareWrite()
     }
 
   PixelFormat pf = PixelData->GetPixelFormat();
+  if ( !pf.IsValid() )
+    {
+    gdcmWarningMacro( "Pixel format is not valid: " << pf );
+    return false;
+    }
   PhotometricInterpretation pi = PixelData->GetPhotometricInterpretation();
   if( pi.GetSamplesPerPixel() != pf.GetSamplesPerPixel() )
     {
-    gdcmWarningMacro( "Photometric Interpretation and Pixel format are not compatible: " 
+    gdcmWarningMacro( "Photometric Interpretation and Pixel format are not compatible: "
       << pi.GetSamplesPerPixel() << " vs " << pf.GetSamplesPerPixel() );
     return false;
     }
@@ -278,7 +284,8 @@ bool PixmapWriter::PrepareWrite()
     assert( pi != PhotometricInterpretation::UNKNOW );
     const char *pistr = PhotometricInterpretation::GetPIString(pi);
     DataElement de( Tag(0x0028, 0x0004 ) );
-    de.SetByteValue( pistr, strlen(pistr) );
+    VL::Type strlenPistr = (VL::Type)strlen(pistr);
+    de.SetByteValue( pistr, strlenPistr );
     de.SetVR( Attribute<0x0028,0x0004>::GetVR() );
     ds.Replace( de );
     }
@@ -316,8 +323,8 @@ bool PixmapWriter::PrepareWrite()
     }
 
   // Overlay Data 60xx
-  unsigned int nOv = PixelData->GetNumberOfOverlays();
-  for( unsigned int ovidx = 0; ovidx < nOv; ++ovidx )
+  gdcm::SequenceOfItems::SizeType nOv = PixelData->GetNumberOfOverlays();
+  for(gdcm::SequenceOfItems::SizeType ovidx = 0; ovidx < nOv; ++ovidx )
     {
     // (6000,0010) US 484                                      #   2, 1 OverlayRows
     // (6000,0011) US 484                                      #   2, 1 OverlayColumns
@@ -335,50 +342,50 @@ bool PixmapWriter::PrepareWrite()
     overlayrows.SetValue( ov.GetRows() );
     de = overlayrows.GetAsDataElement();
     de.GetTag().SetGroup( ov.GetGroup() );
-    ds.Insert( de );
+    ds.Replace( de );
     Attribute<0x6000,0x0011> overlaycolumns;
     overlaycolumns.SetValue( ov.GetColumns() );
     de = overlaycolumns.GetAsDataElement();
     de.GetTag().SetGroup( ov.GetGroup() );
-    ds.Insert( de );
+    ds.Replace( de );
     if( ov.GetDescription() ) // Type 3
       {
       Attribute<0x6000,0x0022> overlaydescription;
       overlaydescription.SetValue( ov.GetDescription() );
       de = overlaydescription.GetAsDataElement();
       de.GetTag().SetGroup( ov.GetGroup() );
-      ds.Insert( de );
+      ds.Replace( de );
       }
     Attribute<0x6000,0x0040> overlaytype; // 'G' or 'R'
     overlaytype.SetValue( ov.GetType() );
     de = overlaytype.GetAsDataElement();
     de.GetTag().SetGroup( ov.GetGroup() );
-    ds.Insert( de );
+    ds.Replace( de );
     Attribute<0x6000,0x0050> overlayorigin;
     overlayorigin.SetValues( ov.GetOrigin() );
     de = overlayorigin.GetAsDataElement();
     de.GetTag().SetGroup( ov.GetGroup() );
-    ds.Insert( de );
+    ds.Replace( de );
     Attribute<0x6000,0x0100> overlaybitsallocated;
     overlaybitsallocated.SetValue( ov.GetBitsAllocated() );
     de = overlaybitsallocated.GetAsDataElement();
     de.GetTag().SetGroup( ov.GetGroup() );
-    ds.Insert( de );
+    ds.Replace( de );
     Attribute<0x6000,0x0102> overlaybitposition;
     overlaybitposition.SetValue( ov.GetBitPosition() );
     de = overlaybitposition.GetAsDataElement();
     de.GetTag().SetGroup( ov.GetGroup() );
-    ds.Insert( de );
+    ds.Replace( de );
 
     // FIXME: for now rewrite 'Overlay in pixel data' still in the pixel data element...
-    if( !ov.IsInPixelData() )
+    //if( !ov.IsInPixelData() )
       {
       const ByteValue & overlaydatabv = ov.GetOverlayData();
       DataElement overlaydata( Tag(0x6000,0x3000) );
       overlaydata.SetByteValue( overlaydatabv.GetPointer(), overlaydatabv.GetLength() );
       overlaydata.SetVR( VR::OW ); // FIXME
       overlaydata.GetTag().SetGroup( ov.GetGroup() );
-      ds.Insert( overlaydata );
+      ds.Replace( overlaydata );
       }
     }
 
@@ -390,11 +397,23 @@ bool PixmapWriter::PrepareWrite()
   const TransferSyntax &ts = PixelData->GetTransferSyntax();
   assert( ts.IsExplicit() || ts.IsImplicit() );
 
-//  if( !ts.IsLossy() && PixelData->IsLossy() )
-//    {
-//    gdcmWarningMacro( "Sorry Pixel Data in encapsulated stream was found to be lossy while Transfer Syntax does not authorized that" );
-//    return false;
-//    }
+  // It is perfectly ok to store a lossy image using a J2K (this is odd, but valid).
+  // as long as your mark LossyImageCompression with value 1
+#if 0
+  // if ts_orig is undefined we need to check ts of Pixel Data comply with itself
+  if( ts_orig == TransferSyntax::TS_END )
+    {
+    if( !ts.CanStoreLossy() && PixelData->IsLossy() )
+      {
+      gdcmWarningMacro( "Sorry Pixel Data in encapsulated stream was found to be "
+        "lossy while Transfer Syntax does not authorized that" );
+      return false;
+      }
+    // Obviously we could also be checking the contrary: trying to store a
+    // lossless compressed JPEG file using a lossy JPEG (compatible) one. But I
+    // do not believe this is an error in this case.
+    }
+#endif
 
   if( /*ts.IsLossy() &&*/ PixelData->IsLossy() )
     {
@@ -424,7 +443,7 @@ bool PixmapWriter::PrepareWrite()
         static const CSComp newvalues2[] = {"ISO_14495_1"};
         at3.SetValues(  newvalues2, 1 );
         }
-      else if ( 
+      else if (
         ts_orig == TransferSyntax::JPEGBaselineProcess1 ||
         ts_orig == TransferSyntax::JPEGExtendedProcess2_4 ||
         ts_orig == TransferSyntax::JPEGExtendedProcess3_5 ||
@@ -486,11 +505,24 @@ bool PixmapWriter::PrepareWrite()
   ms.SetFromFile( GetFile() );
   assert( ms != MediaStorage::MS_END );
 
+  // Most SOP Class support 2D, but let's make sure that 3D is ok:
+  if( PixelData->GetNumberOfDimensions() > 2 )
+    {
+    if( ms.GetModalityDimension() < PixelData->GetNumberOfDimensions() )
+      {
+      gdcmErrorMacro( "Problem with NumberOfDimensions and MediaStorage" );
+#if 0
+      return false;
+#endif
+      }
+    }
+
   const char* msstr = MediaStorage::GetMSString(ms);
   if( !ds.FindDataElement( Tag(0x0008, 0x0016) ) )
     {
     DataElement de( Tag(0x0008, 0x0016 ) );
-    de.SetByteValue( msstr, strlen(msstr) );
+    VL::Type strlenMsstr = (VL::Type)strlen(msstr);
+    de.SetByteValue( msstr, strlenMsstr);
     de.SetVR( Attribute<0x0008, 0x0016>::GetVR() );
     ds.Insert( de );
     }
@@ -500,7 +532,8 @@ bool PixmapWriter::PrepareWrite()
     if( strncmp( bv->GetPointer(), msstr, bv->GetLength() ) != 0 )
       {
       DataElement de = ds.GetDataElement( Tag(0x0008,0x0016) );
-      de.SetByteValue( msstr, strlen(msstr) );
+      VL::Type strlenMsstr = (VL::Type) strlen(msstr);
+      de.SetByteValue( msstr, strlenMsstr );
       ds.Replace( de );
       }
     else
@@ -567,7 +600,8 @@ bool PixmapWriter::PrepareWrite()
     {
     const char *sop = uid.Generate();
     DataElement de( Tag(0x0008,0x0018) );
-    de.SetByteValue( sop, strlen(sop) );
+    VL::Type strlenSOP = (VL::Type) strlen(sop);
+    de.SetByteValue( sop, strlenSOP );
     de.SetVR( Attribute<0x0008, 0x0018>::GetVR() );
     ds.ReplaceEmpty( de );
     }
@@ -577,7 +611,8 @@ bool PixmapWriter::PrepareWrite()
     {
     const char *study = uid.Generate();
     DataElement de( Tag(0x0020,0x000d) );
-    de.SetByteValue( study, strlen(study) );
+    VL::Type strlenStudy= (VL::Type)strlen(study);
+    de.SetByteValue( study, strlenStudy );
     de.SetVR( Attribute<0x0020, 0x000d>::GetVR() );
     ds.ReplaceEmpty( de );
     }
@@ -587,7 +622,8 @@ bool PixmapWriter::PrepareWrite()
     {
     const char *series = uid.Generate();
     DataElement de( Tag(0x0020,0x000e) );
-    de.SetByteValue( series, strlen(series) );
+    VL::Type strlenSeries= (VL::Type)strlen(series);
+    de.SetByteValue( series, strlenSeries );
     de.SetVR( Attribute<0x0020, 0x000e>::GetVR() );
     ds.ReplaceEmpty( de );
     }
@@ -598,7 +634,8 @@ bool PixmapWriter::PrepareWrite()
     {
     const char *tsuid = TransferSyntax::GetTSString( ts );
     DataElement de( Tag(0x0002,0x0010) );
-    de.SetByteValue( tsuid, strlen(tsuid) );
+    VL::Type strlenTSUID = (VL::Type)strlen(tsuid);
+    de.SetByteValue( tsuid, strlenTSUID );
     de.SetVR( Attribute<0x0002, 0x0010>::GetVR() );
     fmi.Replace( de );
     fmi.SetDataSetTransferSyntax(ts);
