@@ -19,7 +19,7 @@
 
 namespace gdcm
 {
-  
+
 class RAWInternals;
 /**
  * \brief RAWCodec class
@@ -36,6 +36,11 @@ public:
 
   bool GetHeaderInfo(std::istream &is, TransferSyntax &ts);
 
+  /// Used by the ImageStreamReader-- converts a read in 
+  /// buffer into one with the proper encodings.
+  bool DecodeBytes(const char* inBytes, size_t inBufferLength,
+    char* outBytes, size_t inOutBufferLength);
+
 protected:
   bool Decode(std::istream &is, std::ostream &os);
 
