@@ -40,7 +40,7 @@ class StringFilter;
  *
  * This filter is dealing with both VRASCII and VRBINARY element, thanks to the
  * help of gdcm::StringFilter
- * 
+ *
  * \warning IMPORTANT In case of file where tags are not ordered (illegal as
  * per DICOM specification), the output will be missing information
  *
@@ -108,6 +108,11 @@ public:
   /// Get all the values found (in lexicographic order) associated with Tag 't'
   ValuesType GetValues(Tag const &t) const;
 
+  /// Get all the values found (in a vector) associated with Tag 't'
+  /// This function is identical to GetValues, but is accessible from the wrapped
+  /// layer (python, C#, java)
+  Directory::FilenamesType GetOrderedValues(Tag const &t) const;
+
   /* ltstr is CRITICAL, otherwise pointers value are used to do the key comparison */
   struct ltstr
     {
@@ -132,6 +137,10 @@ public:
   /// 'valueref'
   const char *GetFilenameFromTagToValue(Tag const &t, const char *valueref) const;
 
+  /// Will loop over all files and return a vector of std::strings of filenames
+  /// where value match the reference value 'valueref'
+  Directory::FilenamesType GetAllFilenamesFromTagToValue(Tag const &t, const char *valueref) const;
+
   /// See GetFilenameFromTagToValue(). This is simply GetFilenameFromTagToValue followed
   // by a call to GetMapping()
   TagToValue const & GetMappingFromTagToValue(Tag const &t, const char *value) const;
