@@ -22,16 +22,17 @@ namespace gdcm
 {
 
 /*
- * Everything done in this code is for the sole purpose of writing interoperable 
+ * Everything done in this code is for the sole purpose of writing interoperable
  * software under Sect. 1201 (f) Reverse Engineering exception of the DMCA.
- * If you believe anything in this code violates any law or any of your rights, 
- * please contact us (gdcm-developers@lists.sourceforge.net) so that we can 
- * find a solution. 
+ * If you believe anything in this code violates any law or any of your rights,
+ * please contact us (gdcm-developers@lists.sourceforge.net) so that we can
+ * find a solution.
  */
 /**
  * \brief SplitMosaicFilter class
  * Class to reshuffle bytes for a SIEMENS Mosaic image
- *
+ * Siemens CSA Image Header
+ * CSA:= Common Siemens Architecture, sometimes also known as Common syngo Architecture
  *
  */
 class GDCM_EXPORT SplitMosaicFilter
@@ -43,6 +44,10 @@ public:
   /// Split the SIEMENS MOSAIC image
   bool Split();
 
+  /// Compute the new dimensions according to private information
+  /// stored in the MOSAIC header.
+  bool ComputeMOSAICDimensions(unsigned int dims[3]);
+
   void SetImage(const Image& image);
   const Image &GetImage() const { return *I; }
   Image &GetImage() { return *I; }
@@ -61,4 +66,3 @@ private:
 } // end namespace gdcm
 
 #endif //GDCMSPLITMOSAICFILTER_H
-
