@@ -15,12 +15,12 @@
 #include "gdcmDummyValueGenerator.h"
 #include "gdcmTesting.h"
 
-int TestDummyValueGenerator(int argc, char *argv[])
+int TestDummyValueGenerator(int , char *[])
 {
-  gdcm::DummyValueGenerator dvg;
+  gdcm::DummyValueGenerator dvg; (void)dvg;
   const char patientid1[] = "hello";
   const char patientid2[] = "hello ";
-  // Because patientid1 & patientid2 are equivalent in DICOM we need to be able to generate 
+  // Because patientid1 & patientid2 are equivalent in DICOM we need to be able to generate
   // identical replacement value in case of de-identifier operation:
 
   const char *ptr1 = gdcm::DummyValueGenerator::Generate( patientid1 );
@@ -37,4 +37,3 @@ int TestDummyValueGenerator(int argc, char *argv[])
 
   return 0;
 }
-
