@@ -60,7 +60,7 @@ int TestImageChangeTransferSyntaxJ2K(const char *filename, bool verbose = false)
     unsigned short ba = reader.GetImage().GetPixelFormat().GetBitsAllocated();
     if( ba == 12 )
       {
-      std::cerr << "fail to change, but that's ok" << std::endl;
+      std::cerr << "fail to change, but that's ok: " << filename << std::endl;
       return 0;
       }
     std::cerr << "Could not change the Transfer Syntax: " << filename << std::endl;
