@@ -17,9 +17,36 @@
 int TestOrientation(int, char *[])
 {
   gdcm::Orientation o;
-  double dircos[] = { 0, 1, 0, 0, 1, 0 };
+{
+  double dircos[] = { 1, 0, 0, 0, 1, 0 };
   gdcm::Orientation::OrientationType type = gdcm::Orientation::GetType(dircos);
 
+  if( type != gdcm::Orientation::AXIAL )
+    {
+    std::cerr << "Should be AXIAL: " << gdcm::Orientation::GetLabel( type ) << std::endl;
+    return 1;
+    }
+}
+{
+  double dircos[] = { 1, 0, 0, 0, 0, 1 };
+  gdcm::Orientation::OrientationType type = gdcm::Orientation::GetType(dircos);
+
+  if( type != gdcm::Orientation::CORONAL )
+    {
+    return 1;
+    }
+}
+{
+  double dircos[] = { 0, 1, 0, 0, 0, -1 };
+  gdcm::Orientation::OrientationType type = gdcm::Orientation::GetType(dircos);
+
+  if( type != gdcm::Orientation::SAGITTAL )
+    {
+    return 1;
+    }
+}
+
+
   if( o.GetObliquityThresholdCosineValue() != 0.8 )
     {
     return 1;
