@@ -20,7 +20,7 @@
 
 // dcmdump /path/to/image/*.dcm 2>&/dev/null| grep 0020 | grep "000e\|000d" | sort | uniq
 //
-// $ find   /images/ -type f -exec dcmdump -s +P 0010,0010 {} \; 
+// $ find   /images/ -type f -exec dcmdump -s +P 0010,0010 {} \;
 
 int TestScannerExtra()
 {
@@ -114,9 +114,15 @@ int TestScanner(int argc, char *argv[])
 
   // Let's get the value for tag t1 in first file:
   gdcm::Scanner::MappingType const &mt = s.GetMappings();
-  const char *filename = d.GetFilenames()[0].c_str();
+  std::string sfilename;
+  sfilename = gdcm::Testing::GetDataRoot();
+  sfilename+= "/test.acr";
+  //const char *filename = d.GetFilenames()[0].c_str();
+  const char *filename = sfilename.c_str();
+  // The following breaks with Papyrus file: PET-cardio-Multiframe-Papyrus.dcm
   unsigned int i = 0;
   gdcm::Scanner::MappingType::const_iterator it = mt.find(filename);
+  assert( it != mt.end() );
   while( it == mt.end() )
     {
     ++i;
@@ -131,7 +137,7 @@ int TestScanner(int argc, char *argv[])
   const gdcm::Scanner::TagToValue &tv = it->second;
   //const std::string &filename = d.GetFilenames()[0];
   gdcm::Scanner::TagToValue::const_iterator it2 = tv.find( t5 );
-  if( it2 == tv.end() || t5 != it2->first ) 
+  if( it2 == tv.end() || t5 != it2->first )
     {
     std::cerr << "Could not find tag:" << t5 << std::endl;
     return 1;
@@ -164,7 +170,7 @@ int TestScanner(int argc, char *argv[])
   for( std::vector<const char *>::const_iterator it = keys.begin(); it != keys.end(); ++it)
     {
     const char *filename = *it;
-    const gdcm::Directory::FilenamesType::const_iterator it2 
+    const gdcm::Directory::FilenamesType::const_iterator it2
       = std::find(filenames.begin(), filenames.end(), filename);
     if( it2 == filenames.end() )
       {
@@ -180,8 +186,7 @@ int TestScanner(int argc, char *argv[])
 
   // puposely discard gdcmDataExtra test, this is just an 'extra' test...
   int b2 = TestScannerExtra(); (void)b2;
-  
+
 
   return 0;
 }
-
