@@ -57,12 +57,12 @@ int TestvtkGDCMImageRead(const char *filename, bool verbose)
   reader->Update();
 
   if( verbose )
-    { 
+    {
     reader->GetOutput()->Print( cout );
     reader->GetMedicalImageProperties()->Print( cout );
     }
 
-  if( verbose )
+  if( verbose && false )
     {
     // Create directory first:
     const char subdir[] = "TestvtkGDCMImageReader";
@@ -88,7 +88,7 @@ int TestvtkGDCMImageRead(const char *filename, bool verbose)
     }
 
   reader->Delete();
-  return 0; 
+  return 0;
 }
 
 int TestvtkGDCMImageReader(int argc, char *argv[])
