@@ -35,6 +35,7 @@
 #endif /*(VTK_MAJOR_VERSION >= 5) || ( VTK_MAJOR_VERSION == 4 && VTK_MINOR_VERSION > 5 )*/
 #include "vtkMatrix4x4.h"
 #include "vtkUnsignedCharArray.h"
+//#include "vtkUnsignedShortArray.h"
 #include "vtkBitArray.h"
 
 #include "gdcmImageReader.h"
@@ -475,7 +476,7 @@ void vtkGDCMImageReader::FillMedicalImageInformation(const gdcm::ImageReader &re
     const gdcm::ByteValue *bvwe = windowexplanation.GetByteValue();
     if( bvwe ) // Can be Type 2
       {
-      int n = this->MedicalImageProperties->GetNumberOfWindowLevelPresets();
+      unsigned int n = this->MedicalImageProperties->GetNumberOfWindowLevelPresets();
       gdcm::Element<gdcm::VR::LO,gdcm::VM::VM1_n> elwe; // window explanation
       gdcm::VR vr = gdcm::VR::LO;
       std::stringstream ss;
@@ -484,11 +485,13 @@ void vtkGDCMImageReader::FillMedicalImageInformation(const gdcm::ImageReader &re
       unsigned int count = gdcm::VM::GetNumberOfElementsFromArray(swe.c_str(), swe.size()); (void)count;
       // I found a case with only one W/L but two comments: WINDOW1\WINDOW2
       // SIEMENS-IncompletePixelData.dcm
+      // oh wait but what if we have the countrary...
       //assert( count >= (unsigned int)n );
-      elwe.SetLength( /*count*/ n * vr.GetSizeof() );
+      elwe.SetLength( count * vr.GetSizeof() );
       ss.str( swe );
       elwe.Read( ss );
-      for(int i = 0; i < n; ++i)
+      unsigned int c = std::min(n, count);
+      for(unsigned int i = 0; i < c; ++i)
         {
         this->MedicalImageProperties->SetNthWindowLevelPresetComment(i, elwe.GetValue(i).c_str() );
         }
@@ -587,7 +590,9 @@ int vtkGDCMImageReader::RequestInformation(vtkInformation *request,
 }
 #endif
 
-gdcm::PixelFormat::ScalarType ComputePixelTypeFromFiles(const char *inputfilename, vtkStringArray *filenames, gdcm::PixelFormat const & pixeltype_ref)
+static gdcm::PixelFormat::ScalarType
+ComputePixelTypeFromFiles(const char *inputfilename, vtkStringArray *filenames,
+  gdcm::Image const & imageref)
 {
   gdcm::PixelFormat::ScalarType outputpt ;
   outputpt = gdcm::PixelFormat::UNKNOWN;
@@ -597,14 +602,7 @@ gdcm::PixelFormat::ScalarType ComputePixelTypeFromFiles(const char *inputfilenam
   // 2. Make sure to decide which Pixel Type to use using *all* slices:
   if( inputfilename )
     {
-    gdcm::ImageReader reader;
-    reader.SetFileName( inputfilename );
-    if( !reader.Read() )
-      {
-      //vtkErrorMacro( "ImageReader failed" );
-      return gdcm::PixelFormat::UNKNOWN;
-      }
-    const gdcm::Image &image = reader.GetImage();
+    const gdcm::Image &image = imageref;
     const gdcm::PixelFormat &pixeltype = image.GetPixelFormat();
     double shift = image.GetIntercept();
     double scale = image.GetSlope();
@@ -618,6 +616,7 @@ gdcm::PixelFormat::ScalarType ComputePixelTypeFromFiles(const char *inputfilenam
   else if ( filenames && filenames->GetNumberOfValues() > 0 )
     {
     std::set< gdcm::PixelFormat::ScalarType > pixeltypes;
+    // FIXME a gdcm::Scanner would be much faster here:
     for(int i = 0; i < filenames->GetNumberOfValues(); ++i )
       {
       const char *filename = filenames->GetValue( i );
@@ -672,7 +671,7 @@ gdcm::PixelFormat::ScalarType ComputePixelTypeFromFiles(const char *inputfilenam
     assert( 0 ); // I do not think this is possible
     }
   //gdcmAssertMacro( outputpt >= pixeltype_ref );
-  (void)pixeltype_ref;
+  //(void)pixeltype_ref;
 
   return outputpt;
 }
@@ -720,7 +719,7 @@ int vtkGDCMImageReader::RequestInformationCompat()
   reader.SetFileName( filename );
   if( !reader.Read() )
     {
-    vtkErrorMacro( "ImageReader failed" );
+    vtkErrorMacro( "ImageReader failed on " << filename );
     return 0;
     }
   const gdcm::Image &image = reader.GetImage();
@@ -835,7 +834,14 @@ int vtkGDCMImageReader::RequestInformationCompat()
   this->Scale = image.GetSlope();
 
   //gdcm::PixelFormat::ScalarType outputpt = pixeltype;
-  gdcm::PixelFormat::ScalarType outputpt = ComputePixelTypeFromFiles(this->FileName, this->FileNames, pixeltype);
+  gdcm::PixelFormat::ScalarType outputpt =
+    ComputePixelTypeFromFiles(this->FileName, this->FileNames, image);
+  if( this->FileName )
+    {
+    // We should test that outputpt is 8 when BitsAllocated = 16 / Bits Stored = 8
+    // BUT we should test that output is 16 when BitsAllocated = 16 / BitsStored = 12
+    // assert( outputpt == pixeltype );
+    }
 
   // Compute output pixel format when Rescaling:
 //  if( this->Shift != 0 || this->Scale != 1. )
@@ -1136,7 +1142,12 @@ int vtkGDCMImageReader::LoadSingleFile(const char *filename, char *pointer, unsi
     char * copy = new char[len];
     //memcpy(copy, pointer, len);
     image.GetBuffer(copy);
-    r.Rescale(pointer,copy,len);
+    if( !r.Rescale(pointer,copy,len) )
+      {
+      vtkErrorMacro( "Could not Rescale" );
+      // problem with gdcmData/3E768EB7.dcm
+      return 0;
+      }
     delete[] copy;
     // WARNING: sizeof(Real World Value) != sizeof(Stored Pixel)
     outlen = data->GetScalarSize() * data->GetNumberOfPoints() / data->GetDimensions()[2];
@@ -1266,7 +1277,7 @@ int vtkGDCMImageReader::LoadSingleFile(const char *filename, char *pointer, unsi
       data->GetPointData()->GetScalars()->SetLookupTable( vtklut );
       vtklut->Delete();
       }
-    else 
+    else
       {
 #if (VTK_MAJOR_VERSION >= 5)
       assert( lut.GetBitSample() == 16 );
@@ -1499,4 +1510,3 @@ void vtkGDCMImageReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os,indent);
 }
-
