@@ -248,8 +248,8 @@ int vtkGDCMThreadedImageReader::RequestInformation(vtkInformation *request,
     // Overlays:
     //case OverlayPortNumber:
     default:
-      outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(), 
-        this->DataExtent[0], this->DataExtent[1], 
+      outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(),
+        this->DataExtent[0], this->DataExtent[1],
         this->DataExtent[2], this->DataExtent[3],
         0,0 );
       vtkDataObject::SetPointDataActiveScalarInfo(outInfo, VTK_UNSIGNED_CHAR, 1);
@@ -328,7 +328,7 @@ void *ReadFilesThread(void *voidparams)
     // len -> sizeof stored image
     // params->len sizeof world value image (after transform)
     if( shift == 1 && scale == 0 )
-      assert( len == params->len ); // that would be very bad 
+      assert( len == params->len ); // that would be very bad
 
     char * pointer = params->scalarpointer;
     //memcpy(pointer + file*len, tempimage, len);
@@ -423,7 +423,14 @@ void vtkGDCMThreadedImageReader::ReadFiles(unsigned int nfiles, const char *file
     overlayscalarpointer = static_cast<unsigned char*>(overlayoutput->GetScalarPointer());
     }
 
+#ifdef _WIN32
+  // mingw
+  SYSTEM_INFO info;
+  GetSystemInfo (&info);
+  const unsigned int nprocs = info.dwNumberOfProcessors;
+#else
   const unsigned int nprocs = sysconf( _SC_NPROCESSORS_ONLN );
+#endif
   const unsigned int nthreads = std::min( nprocs, nfiles );
   threadparams *params = new threadparams[nthreads];
 
@@ -488,7 +495,7 @@ void vtkGDCMThreadedImageReader::ReadFiles(unsigned int nfiles, const char *file
 
   pthread_mutex_destroy(&lock);
   delete[] params;
- 
+
 #if 0
   // For some reason writing down the file is painfully slow...
   vtkStructuredPointsWriter *writer = vtkStructuredPointsWriter::New();
@@ -517,7 +524,7 @@ int vtkGDCMThreadedImageReader::RequestData(vtkInformation *vtkNotUsed(request),
   for(int i = 0; i < this->GetNumberOfOutputPorts(); ++i)
     {
     // Copy/paste from vtkImageAlgorithm::AllocateScalars. Cf. "this needs to be fixed -Ken"
-    vtkStreamingDemandDrivenPipeline *sddp = 
+    vtkStreamingDemandDrivenPipeline *sddp =
       vtkStreamingDemandDrivenPipeline::SafeDownCast(this->GetExecutive());
     if (sddp)
       {
@@ -571,4 +578,3 @@ void vtkGDCMThreadedImageReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os,indent);
 }
-
