@@ -1,5 +1,21 @@
 /*=========================================================================
 
+  Program: GDCM (Grassroots DICOM). A DICOM library
+  Module:  $URL$
+
+  Copyright (c) 2006-2010 Mathieu Malaterre
+  All rights reserved.
+  See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
+
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+     PURPOSE.  See the above copyright notice for more information.
+
+=========================================================================*/
+/*=========================================================================
+
+  Portions of this file are subject to the VTK Toolkit Version 3 copyright.
+
   Program:   Visualization Toolkit
   Module:    $RCSfile: vtkImageMapToColors16.h,v $
 
@@ -44,7 +60,7 @@ public:
   vtkGetObjectMacro(LookupTable,vtkScalarsToColors);
 
   // Description:
-  // Set the output format, the default is RGBA.  
+  // Set the output format, the default is RGBA.
   vtkSetMacro(OutputFormat,int);
   vtkGetMacro(OutputFormat,int);
   void SetOutputFormatToRGBA() { this->OutputFormat = VTK_RGBA; };
@@ -73,7 +89,7 @@ protected:
   ~vtkImageMapToColors16();
 
   virtual int RequestInformation (vtkInformation *, vtkInformationVector **, vtkInformationVector *);
-  
+
   void ThreadedRequestData(vtkInformation *request,
                            vtkInformationVector **inputVector,
                            vtkInformationVector *outputVector,
@@ -86,7 +102,7 @@ protected:
 
   vtkScalarsToColors *LookupTable;
   int OutputFormat;
-  
+
   int ActiveComponent;
   int PassAlphaToOutput;
 
@@ -97,10 +113,3 @@ private:
 };
 
 #endif
-
-
-
-
-
-
-
