@@ -1,5 +1,21 @@
 /*=========================================================================
 
+  Program: GDCM (Grassroots DICOM). A DICOM library
+  Module:  $URL$
+
+  Copyright (c) 2006-2010 Mathieu Malaterre
+  All rights reserved.
+  See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
+
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+     PURPOSE.  See the above copyright notice for more information.
+
+=========================================================================*/
+/*=========================================================================
+
+  Portions of this file are subject to the VTK Toolkit Version 3 copyright.
+
   Program:   Visualization Toolkit
   Module:    $RCSfile: vtkImageMapToWindowLevelColors2.h,v $
 
@@ -17,9 +33,9 @@
 // The vtkImageMapToWindowLevelColors2 filter will take an input image of any
 // valid scalar type, and map the first component of the image through a
 // lookup table.  This resulting color will be modulated with value obtained
-// by a window / level operation. The result is an image of type 
-// VTK_UNSIGNED_CHAR. If the lookup table is not set, or is set to NULL, then 
-// the input data will be passed through if it is already of type 
+// by a window / level operation. The result is an image of type
+// VTK_UNSIGNED_CHAR. If the lookup table is not set, or is set to NULL, then
+// the input data will be passed through if it is already of type
 // UNSIGNED_CHAR.
 //
 // .SECTION See Also
@@ -38,19 +54,19 @@ public:
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
-  // Set / Get the Window to use -> modulation will be performed on the 
+  // Set / Get the Window to use -> modulation will be performed on the
   // color based on (S - (L - W/2))/W where S is the scalar value, L is
   // the level and W is the window.
   vtkSetMacro( Window, double );
   vtkGetMacro( Window, double );
-  
+
   // Description:
-  // Set / Get the Level to use -> modulation will be performed on the 
+  // Set / Get the Level to use -> modulation will be performed on the
   // color based on (S - (L - W/2))/W where S is the scalar value, L is
   // the level and W is the window.
   vtkSetMacro( Level, double );
   vtkGetMacro( Level, double );
-  
+
 protected:
   vtkImageMapToWindowLevelColors2();
   ~vtkImageMapToWindowLevelColors2();
@@ -67,17 +83,10 @@ protected:
 
   double Window;
   double Level;
-  
+
 private:
   vtkImageMapToWindowLevelColors2(const vtkImageMapToWindowLevelColors2&);  // Not implemented.
   void operator=(const vtkImageMapToWindowLevelColors2&);  // Not implemented.
 };
 
 #endif
-
-
-
-
-
-
-
