@@ -1,5 +1,21 @@
 /*=========================================================================
 
+  Program: GDCM (Grassroots DICOM). A DICOM library
+  Module:  $URL$
+
+  Copyright (c) 2006-2010 Mathieu Malaterre
+  All rights reserved.
+  See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
+
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+     PURPOSE.  See the above copyright notice for more information.
+
+=========================================================================*/
+/*=========================================================================
+
+  Portions of this file are subject to the VTK Toolkit Version 3 copyright.
+
   Program:   Visualization Toolkit
   Module:    $RCSfile: vtkLookupTable16.h,v $
 
@@ -12,13 +28,13 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-// .NAME vtkLookupTable16 - 
+// .NAME vtkLookupTable16 -
 // .SECTION Description
 //
 // .SECTION Caveats
 //
 // .SECTION See Also
-// vtkLookupTable 
+// vtkLookupTable
 
 #ifndef VTKLOOKUPTABLE16_H
 #define VTKLOOKUPTABLE16_H
@@ -30,7 +46,7 @@ class VTK_EXPORT vtkLookupTable16 : public vtkLookupTable
 {
 public:
   static vtkLookupTable16 *New();
-  
+
   vtkTypeRevisionMacro(vtkLookupTable16,vtkLookupTable);
   void PrintSelf(ostream& os, vtkIndent indent);
 
@@ -49,20 +65,20 @@ protected:
 
   vtkUnsignedShortArray *Table16;
 
-void MapScalarsThroughTable2(void *input, 
+void MapScalarsThroughTable2(void *input,
                                              unsigned char *output,
-                                             int inputDataType, 
+                                             int inputDataType,
                                              int numberOfValues,
                                              int inputIncrement,
                                              int outputFormat);
- 
+
 private:
   vtkLookupTable16(const vtkLookupTable16&);  // Not implemented.
   void operator=(const vtkLookupTable16&);  // Not implemented.
 };
 
 //----------------------------------------------------------------------------
-inline unsigned char *vtkLookupTable16::WritePointer(const vtkIdType id, 
+inline unsigned char *vtkLookupTable16::WritePointer(const vtkIdType id,
                                                    const int number)
 {
   //this->InsertTime.Modified();
@@ -70,6 +86,3 @@ inline unsigned char *vtkLookupTable16::WritePointer(const vtkIdType id,
 }
 
 #endif
-
-
-
