@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 ############################################################################
 #
 #  Program: GDCM (Grassroots DICOM). A DICOM library
@@ -42,6 +43,7 @@ blacklist = (
 "String"
 "CodeString"
 "Parser"
+"TagToVR"
 
 # DataDict:
 "TagToType"
@@ -71,7 +73,7 @@ blacklist = (
 # Do not expose low level jpeg implementation detail
 "JPEG8Codec"
 "JPEG12Codec"
-"JPEG16Codec" 
+"JPEG16Codec"
 "JPEG2000Codec"
 # For now remove the codec part:
 "ImageCodec"
@@ -124,4 +126,3 @@ if __name__ == "__main__":
 
   print "number of class not wrap:%d"%total
   sys.exit(total)
-
